/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiAssessmentEssay
    /// </summary>
    [DataContract(Name = "mi_assessmentEssay")]
    public partial class MiAssessmentEssay : IEquatable<MiAssessmentEssay>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiAssessmentEssay" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiAssessmentEssay() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiAssessmentEssay" /> class.
        /// </summary>
        /// <param name="essayCategoryDescriptor">The indicator of the assessment essay type. (required).</param>
        /// <param name="possibleScore">The total points possible that is achievable across all essay. (required).</param>
        /// <param name="rubrics">An unordered collection of assessmentEssayRubrics. The essay rubric association for an assessment essay. (required).</param>
        public MiAssessmentEssay(string essayCategoryDescriptor = default(string), string possibleScore = default(string), List<MiAssessmentEssayRubric> rubrics = default(List<MiAssessmentEssayRubric>))
        {
            // to ensure "essayCategoryDescriptor" is required (not null)
            if (essayCategoryDescriptor == null)
            {
                throw new ArgumentNullException("essayCategoryDescriptor is a required property for MiAssessmentEssay and cannot be null");
            }
            this.EssayCategoryDescriptor = essayCategoryDescriptor;
            // to ensure "possibleScore" is required (not null)
            if (possibleScore == null)
            {
                throw new ArgumentNullException("possibleScore is a required property for MiAssessmentEssay and cannot be null");
            }
            this.PossibleScore = possibleScore;
            // to ensure "rubrics" is required (not null)
            if (rubrics == null)
            {
                throw new ArgumentNullException("rubrics is a required property for MiAssessmentEssay and cannot be null");
            }
            this.Rubrics = rubrics;
        }

        /// <summary>
        /// The indicator of the assessment essay type.
        /// </summary>
        /// <value>The indicator of the assessment essay type.</value>
        [DataMember(Name = "essayCategoryDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string EssayCategoryDescriptor { get; set; }

        /// <summary>
        /// The total points possible that is achievable across all essay.
        /// </summary>
        /// <value>The total points possible that is achievable across all essay.</value>
        [DataMember(Name = "possibleScore", IsRequired = true, EmitDefaultValue = false)]
        public string PossibleScore { get; set; }

        /// <summary>
        /// An unordered collection of assessmentEssayRubrics. The essay rubric association for an assessment essay.
        /// </summary>
        /// <value>An unordered collection of assessmentEssayRubrics. The essay rubric association for an assessment essay.</value>
        [DataMember(Name = "rubrics", IsRequired = true, EmitDefaultValue = false)]
        public List<MiAssessmentEssayRubric> Rubrics { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiAssessmentEssay {\n");
            sb.Append("  EssayCategoryDescriptor: ").Append(EssayCategoryDescriptor).Append("\n");
            sb.Append("  PossibleScore: ").Append(PossibleScore).Append("\n");
            sb.Append("  Rubrics: ").Append(Rubrics).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiAssessmentEssay);
        }

        /// <summary>
        /// Returns true if MiAssessmentEssay instances are equal
        /// </summary>
        /// <param name="input">Instance of MiAssessmentEssay to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiAssessmentEssay input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.EssayCategoryDescriptor == input.EssayCategoryDescriptor ||
                    (this.EssayCategoryDescriptor != null &&
                    this.EssayCategoryDescriptor.Equals(input.EssayCategoryDescriptor))
                ) && 
                (
                    this.PossibleScore == input.PossibleScore ||
                    (this.PossibleScore != null &&
                    this.PossibleScore.Equals(input.PossibleScore))
                ) && 
                (
                    this.Rubrics == input.Rubrics ||
                    this.Rubrics != null &&
                    input.Rubrics != null &&
                    this.Rubrics.SequenceEqual(input.Rubrics)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.EssayCategoryDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EssayCategoryDescriptor.GetHashCode();
                }
                if (this.PossibleScore != null)
                {
                    hashCode = (hashCode * 59) + this.PossibleScore.GetHashCode();
                }
                if (this.Rubrics != null)
                {
                    hashCode = (hashCode * 59) + this.Rubrics.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // EssayCategoryDescriptor (string) maxLength
            if (this.EssayCategoryDescriptor != null && this.EssayCategoryDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EssayCategoryDescriptor, length must be less than 306.", new [] { "EssayCategoryDescriptor" });
            }

            // PossibleScore (string) maxLength
            if (this.PossibleScore != null && this.PossibleScore.Length > 35)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for PossibleScore, length must be less than 35.", new [] { "PossibleScore" });
            }

            yield break;
        }
    }

}
