/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiBalanceSheet
    /// </summary>
    [DataContract(Name = "mi_balanceSheet")]
    public partial class MiBalanceSheet : IEquatable<MiBalanceSheet>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiBalanceSheet" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiBalanceSheet() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiBalanceSheet" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="balanceSheetMajorClassDescriptor">The basic account identifier for recording transactions. (required).</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the balance sheet is submitted. (required).</param>
        /// <param name="educationOrganizationReference">educationOrganizationReference (required).</param>
        /// <param name="balanceSheetOptional">An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection..</param>
        /// <param name="endingBalance">Ending balance for the fund code / major class code submitted. (required).</param>
        /// <param name="fundCodes">An unordered collection of balanceSheetFundCodes. The independent fisal and accounting entity for balance sheet transaction..</param>
        /// <param name="suffixCode">The code used to further define/distinguish between sources (four positions). Field is included in the Michigan School Accounting Manual Chart of Accounts but is an optional field in FID collection. Provided should district&#39;s choose to submit data from the districti&#39;s accounting system if this field is used..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiBalanceSheet(string id = default(string), string balanceSheetMajorClassDescriptor = default(string), int fiscalYear = default(int), EdFiEducationOrganizationReference educationOrganizationReference = default(EdFiEducationOrganizationReference), string balanceSheetOptional = default(string), double endingBalance = default(double), List<MiBalanceSheetFundCode> fundCodes = default(List<MiBalanceSheetFundCode>), string suffixCode = default(string), string etag = default(string))
        {
            // to ensure "balanceSheetMajorClassDescriptor" is required (not null)
            if (balanceSheetMajorClassDescriptor == null)
            {
                throw new ArgumentNullException("balanceSheetMajorClassDescriptor is a required property for MiBalanceSheet and cannot be null");
            }
            this.BalanceSheetMajorClassDescriptor = balanceSheetMajorClassDescriptor;
            this.FiscalYear = fiscalYear;
            // to ensure "educationOrganizationReference" is required (not null)
            if (educationOrganizationReference == null)
            {
                throw new ArgumentNullException("educationOrganizationReference is a required property for MiBalanceSheet and cannot be null");
            }
            this.EducationOrganizationReference = educationOrganizationReference;
            this.EndingBalance = endingBalance;
            this.Id = id;
            this.BalanceSheetOptional = balanceSheetOptional;
            this.FundCodes = fundCodes;
            this.SuffixCode = suffixCode;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// The basic account identifier for recording transactions.
        /// </summary>
        /// <value>The basic account identifier for recording transactions.</value>
        [DataMember(Name = "balanceSheetMajorClassDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string BalanceSheetMajorClassDescriptor { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the balance sheet is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the balance sheet is submitted.</value>
        [DataMember(Name = "fiscalYear", IsRequired = true, EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// Gets or Sets EducationOrganizationReference
        /// </summary>
        [DataMember(Name = "educationOrganizationReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiEducationOrganizationReference EducationOrganizationReference { get; set; }

        /// <summary>
        /// An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection.
        /// </summary>
        /// <value>An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection.</value>
        [DataMember(Name = "balanceSheetOptional", EmitDefaultValue = true)]
        public string BalanceSheetOptional { get; set; }

        /// <summary>
        /// Ending balance for the fund code / major class code submitted.
        /// </summary>
        /// <value>Ending balance for the fund code / major class code submitted.</value>
        [DataMember(Name = "endingBalance", IsRequired = true, EmitDefaultValue = false)]
        public double EndingBalance { get; set; }

        /// <summary>
        /// An unordered collection of balanceSheetFundCodes. The independent fisal and accounting entity for balance sheet transaction.
        /// </summary>
        /// <value>An unordered collection of balanceSheetFundCodes. The independent fisal and accounting entity for balance sheet transaction.</value>
        [DataMember(Name = "fundCodes", EmitDefaultValue = false)]
        public List<MiBalanceSheetFundCode> FundCodes { get; set; }

        /// <summary>
        /// The code used to further define/distinguish between sources (four positions). Field is included in the Michigan School Accounting Manual Chart of Accounts but is an optional field in FID collection. Provided should district&#39;s choose to submit data from the districti&#39;s accounting system if this field is used.
        /// </summary>
        /// <value>The code used to further define/distinguish between sources (four positions). Field is included in the Michigan School Accounting Manual Chart of Accounts but is an optional field in FID collection. Provided should district&#39;s choose to submit data from the districti&#39;s accounting system if this field is used.</value>
        [DataMember(Name = "suffixCode", EmitDefaultValue = true)]
        public string SuffixCode { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiBalanceSheet {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  BalanceSheetMajorClassDescriptor: ").Append(BalanceSheetMajorClassDescriptor).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  EducationOrganizationReference: ").Append(EducationOrganizationReference).Append("\n");
            sb.Append("  BalanceSheetOptional: ").Append(BalanceSheetOptional).Append("\n");
            sb.Append("  EndingBalance: ").Append(EndingBalance).Append("\n");
            sb.Append("  FundCodes: ").Append(FundCodes).Append("\n");
            sb.Append("  SuffixCode: ").Append(SuffixCode).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiBalanceSheet);
        }

        /// <summary>
        /// Returns true if MiBalanceSheet instances are equal
        /// </summary>
        /// <param name="input">Instance of MiBalanceSheet to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiBalanceSheet input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.BalanceSheetMajorClassDescriptor == input.BalanceSheetMajorClassDescriptor ||
                    (this.BalanceSheetMajorClassDescriptor != null &&
                    this.BalanceSheetMajorClassDescriptor.Equals(input.BalanceSheetMajorClassDescriptor))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.EducationOrganizationReference == input.EducationOrganizationReference ||
                    (this.EducationOrganizationReference != null &&
                    this.EducationOrganizationReference.Equals(input.EducationOrganizationReference))
                ) && 
                (
                    this.BalanceSheetOptional == input.BalanceSheetOptional ||
                    (this.BalanceSheetOptional != null &&
                    this.BalanceSheetOptional.Equals(input.BalanceSheetOptional))
                ) && 
                (
                    this.EndingBalance == input.EndingBalance ||
                    this.EndingBalance.Equals(input.EndingBalance)
                ) && 
                (
                    this.FundCodes == input.FundCodes ||
                    this.FundCodes != null &&
                    input.FundCodes != null &&
                    this.FundCodes.SequenceEqual(input.FundCodes)
                ) && 
                (
                    this.SuffixCode == input.SuffixCode ||
                    (this.SuffixCode != null &&
                    this.SuffixCode.Equals(input.SuffixCode))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.BalanceSheetMajorClassDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.BalanceSheetMajorClassDescriptor.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                if (this.EducationOrganizationReference != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationReference.GetHashCode();
                }
                if (this.BalanceSheetOptional != null)
                {
                    hashCode = (hashCode * 59) + this.BalanceSheetOptional.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.EndingBalance.GetHashCode();
                if (this.FundCodes != null)
                {
                    hashCode = (hashCode * 59) + this.FundCodes.GetHashCode();
                }
                if (this.SuffixCode != null)
                {
                    hashCode = (hashCode * 59) + this.SuffixCode.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // BalanceSheetMajorClassDescriptor (string) maxLength
            if (this.BalanceSheetMajorClassDescriptor != null && this.BalanceSheetMajorClassDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for BalanceSheetMajorClassDescriptor, length must be less than 306.", new [] { "BalanceSheetMajorClassDescriptor" });
            }

            // BalanceSheetOptional (string) maxLength
            if (this.BalanceSheetOptional != null && this.BalanceSheetOptional.Length > 16)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for BalanceSheetOptional, length must be less than 16.", new [] { "BalanceSheetOptional" });
            }

            // SuffixCode (string) maxLength
            if (this.SuffixCode != null && this.SuffixCode.Length > 2)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for SuffixCode, length must be less than 2.", new [] { "SuffixCode" });
            }

            yield break;
        }
    }

}
