/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiEducationServiceProviderExpenditure
    /// </summary>
    [DataContract(Name = "mi_educationServiceProviderExpenditure")]
    public partial class MiEducationServiceProviderExpenditure : IEquatable<MiEducationServiceProviderExpenditure>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiEducationServiceProviderExpenditure" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiEducationServiceProviderExpenditure() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiEducationServiceProviderExpenditure" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="espFunctionCodeDescriptor">To indicate the basic account identifier for ESP expenditures. It describes the activity for which a service or material is acquired. (required).</param>
        /// <param name="espObjectCodeDescriptor">To indicate the service or commodity obtained as the result of a specific ESP expenditure. (required).</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the ESP is submitted. (required).</param>
        /// <param name="educationOrganizationReference">educationOrganizationReference (required).</param>
        /// <param name="amount">Amount for the ESP expenditure submitted. (required).</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiEducationServiceProviderExpenditure(string id = default(string), string espFunctionCodeDescriptor = default(string), string espObjectCodeDescriptor = default(string), int fiscalYear = default(int), EdFiEducationOrganizationReference educationOrganizationReference = default(EdFiEducationOrganizationReference), double amount = default(double), string etag = default(string))
        {
            // to ensure "espFunctionCodeDescriptor" is required (not null)
            if (espFunctionCodeDescriptor == null)
            {
                throw new ArgumentNullException("espFunctionCodeDescriptor is a required property for MiEducationServiceProviderExpenditure and cannot be null");
            }
            this.EspFunctionCodeDescriptor = espFunctionCodeDescriptor;
            // to ensure "espObjectCodeDescriptor" is required (not null)
            if (espObjectCodeDescriptor == null)
            {
                throw new ArgumentNullException("espObjectCodeDescriptor is a required property for MiEducationServiceProviderExpenditure and cannot be null");
            }
            this.EspObjectCodeDescriptor = espObjectCodeDescriptor;
            this.FiscalYear = fiscalYear;
            // to ensure "educationOrganizationReference" is required (not null)
            if (educationOrganizationReference == null)
            {
                throw new ArgumentNullException("educationOrganizationReference is a required property for MiEducationServiceProviderExpenditure and cannot be null");
            }
            this.EducationOrganizationReference = educationOrganizationReference;
            this.Amount = amount;
            this.Id = id;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// To indicate the basic account identifier for ESP expenditures. It describes the activity for which a service or material is acquired.
        /// </summary>
        /// <value>To indicate the basic account identifier for ESP expenditures. It describes the activity for which a service or material is acquired.</value>
        [DataMember(Name = "espFunctionCodeDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string EspFunctionCodeDescriptor { get; set; }

        /// <summary>
        /// To indicate the service or commodity obtained as the result of a specific ESP expenditure.
        /// </summary>
        /// <value>To indicate the service or commodity obtained as the result of a specific ESP expenditure.</value>
        [DataMember(Name = "espObjectCodeDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string EspObjectCodeDescriptor { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the ESP is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the ESP is submitted.</value>
        [DataMember(Name = "fiscalYear", IsRequired = true, EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// Gets or Sets EducationOrganizationReference
        /// </summary>
        [DataMember(Name = "educationOrganizationReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiEducationOrganizationReference EducationOrganizationReference { get; set; }

        /// <summary>
        /// Amount for the ESP expenditure submitted.
        /// </summary>
        /// <value>Amount for the ESP expenditure submitted.</value>
        [DataMember(Name = "amount", IsRequired = true, EmitDefaultValue = false)]
        public double Amount { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiEducationServiceProviderExpenditure {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  EspFunctionCodeDescriptor: ").Append(EspFunctionCodeDescriptor).Append("\n");
            sb.Append("  EspObjectCodeDescriptor: ").Append(EspObjectCodeDescriptor).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  EducationOrganizationReference: ").Append(EducationOrganizationReference).Append("\n");
            sb.Append("  Amount: ").Append(Amount).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiEducationServiceProviderExpenditure);
        }

        /// <summary>
        /// Returns true if MiEducationServiceProviderExpenditure instances are equal
        /// </summary>
        /// <param name="input">Instance of MiEducationServiceProviderExpenditure to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiEducationServiceProviderExpenditure input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.EspFunctionCodeDescriptor == input.EspFunctionCodeDescriptor ||
                    (this.EspFunctionCodeDescriptor != null &&
                    this.EspFunctionCodeDescriptor.Equals(input.EspFunctionCodeDescriptor))
                ) && 
                (
                    this.EspObjectCodeDescriptor == input.EspObjectCodeDescriptor ||
                    (this.EspObjectCodeDescriptor != null &&
                    this.EspObjectCodeDescriptor.Equals(input.EspObjectCodeDescriptor))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.EducationOrganizationReference == input.EducationOrganizationReference ||
                    (this.EducationOrganizationReference != null &&
                    this.EducationOrganizationReference.Equals(input.EducationOrganizationReference))
                ) && 
                (
                    this.Amount == input.Amount ||
                    this.Amount.Equals(input.Amount)
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.EspFunctionCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EspFunctionCodeDescriptor.GetHashCode();
                }
                if (this.EspObjectCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EspObjectCodeDescriptor.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                if (this.EducationOrganizationReference != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationReference.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.Amount.GetHashCode();
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // EspFunctionCodeDescriptor (string) maxLength
            if (this.EspFunctionCodeDescriptor != null && this.EspFunctionCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EspFunctionCodeDescriptor, length must be less than 306.", new [] { "EspFunctionCodeDescriptor" });
            }

            // EspObjectCodeDescriptor (string) maxLength
            if (this.EspObjectCodeDescriptor != null && this.EspObjectCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EspObjectCodeDescriptor, length must be less than 306.", new [] { "EspObjectCodeDescriptor" });
            }

            yield break;
        }
    }

}
