/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiExpenditure
    /// </summary>
    [DataContract(Name = "mi_expenditure")]
    public partial class MiExpenditure : IEquatable<MiExpenditure>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiExpenditure" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiExpenditure() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiExpenditure" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the expenditure is submitted. (required).</param>
        /// <param name="functionCodeDescriptor">To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired. (required).</param>
        /// <param name="grantCodeDescriptor">To indicate various grant programs/funding source. (required).</param>
        /// <param name="objectCodeDescriptor">To indicate the service or commodity obtained as the result of a specific expenditure. (required).</param>
        /// <param name="educationOrganizationReference">educationOrganizationReference (required).</param>
        /// <param name="schoolReference">schoolReference (required).</param>
        /// <param name="amount">Amount for the expenditure submitted. (required).</param>
        /// <param name="expenditureOtherOptional">A dimension available to further define a school district&#39;s activities..</param>
        /// <param name="fundCodes">An unordered collection of expenditureFundCodes. The independent fisal and accounting entity for expenditure transaction..</param>
        /// <param name="programCodeDescriptor">To indicate a plan of activities and procedures designed to accomplish predetermined objective or set of allied objectives..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiExpenditure(string id = default(string), int fiscalYear = default(int), string functionCodeDescriptor = default(string), string grantCodeDescriptor = default(string), string objectCodeDescriptor = default(string), EdFiEducationOrganizationReference educationOrganizationReference = default(EdFiEducationOrganizationReference), EdFiSchoolReference schoolReference = default(EdFiSchoolReference), double amount = default(double), string expenditureOtherOptional = default(string), List<MiExpenditureFundCode> fundCodes = default(List<MiExpenditureFundCode>), string programCodeDescriptor = default(string), string etag = default(string))
        {
            this.FiscalYear = fiscalYear;
            // to ensure "functionCodeDescriptor" is required (not null)
            if (functionCodeDescriptor == null)
            {
                throw new ArgumentNullException("functionCodeDescriptor is a required property for MiExpenditure and cannot be null");
            }
            this.FunctionCodeDescriptor = functionCodeDescriptor;
            // to ensure "grantCodeDescriptor" is required (not null)
            if (grantCodeDescriptor == null)
            {
                throw new ArgumentNullException("grantCodeDescriptor is a required property for MiExpenditure and cannot be null");
            }
            this.GrantCodeDescriptor = grantCodeDescriptor;
            // to ensure "objectCodeDescriptor" is required (not null)
            if (objectCodeDescriptor == null)
            {
                throw new ArgumentNullException("objectCodeDescriptor is a required property for MiExpenditure and cannot be null");
            }
            this.ObjectCodeDescriptor = objectCodeDescriptor;
            // to ensure "educationOrganizationReference" is required (not null)
            if (educationOrganizationReference == null)
            {
                throw new ArgumentNullException("educationOrganizationReference is a required property for MiExpenditure and cannot be null");
            }
            this.EducationOrganizationReference = educationOrganizationReference;
            // to ensure "schoolReference" is required (not null)
            if (schoolReference == null)
            {
                throw new ArgumentNullException("schoolReference is a required property for MiExpenditure and cannot be null");
            }
            this.SchoolReference = schoolReference;
            this.Amount = amount;
            this.Id = id;
            this.ExpenditureOtherOptional = expenditureOtherOptional;
            this.FundCodes = fundCodes;
            this.ProgramCodeDescriptor = programCodeDescriptor;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the expenditure is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the expenditure is submitted.</value>
        [DataMember(Name = "fiscalYear", IsRequired = true, EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired.
        /// </summary>
        /// <value>To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired.</value>
        [DataMember(Name = "functionCodeDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string FunctionCodeDescriptor { get; set; }

        /// <summary>
        /// To indicate various grant programs/funding source.
        /// </summary>
        /// <value>To indicate various grant programs/funding source.</value>
        [DataMember(Name = "grantCodeDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string GrantCodeDescriptor { get; set; }

        /// <summary>
        /// To indicate the service or commodity obtained as the result of a specific expenditure.
        /// </summary>
        /// <value>To indicate the service or commodity obtained as the result of a specific expenditure.</value>
        [DataMember(Name = "objectCodeDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string ObjectCodeDescriptor { get; set; }

        /// <summary>
        /// Gets or Sets EducationOrganizationReference
        /// </summary>
        [DataMember(Name = "educationOrganizationReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiEducationOrganizationReference EducationOrganizationReference { get; set; }

        /// <summary>
        /// Gets or Sets SchoolReference
        /// </summary>
        [DataMember(Name = "schoolReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiSchoolReference SchoolReference { get; set; }

        /// <summary>
        /// Amount for the expenditure submitted.
        /// </summary>
        /// <value>Amount for the expenditure submitted.</value>
        [DataMember(Name = "amount", IsRequired = true, EmitDefaultValue = false)]
        public double Amount { get; set; }

        /// <summary>
        /// A dimension available to further define a school district&#39;s activities.
        /// </summary>
        /// <value>A dimension available to further define a school district&#39;s activities.</value>
        [DataMember(Name = "expenditureOtherOptional", EmitDefaultValue = true)]
        public string ExpenditureOtherOptional { get; set; }

        /// <summary>
        /// An unordered collection of expenditureFundCodes. The independent fisal and accounting entity for expenditure transaction.
        /// </summary>
        /// <value>An unordered collection of expenditureFundCodes. The independent fisal and accounting entity for expenditure transaction.</value>
        [DataMember(Name = "fundCodes", EmitDefaultValue = false)]
        public List<MiExpenditureFundCode> FundCodes { get; set; }

        /// <summary>
        /// To indicate a plan of activities and procedures designed to accomplish predetermined objective or set of allied objectives.
        /// </summary>
        /// <value>To indicate a plan of activities and procedures designed to accomplish predetermined objective or set of allied objectives.</value>
        [DataMember(Name = "programCodeDescriptor", EmitDefaultValue = true)]
        public string ProgramCodeDescriptor { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiExpenditure {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  FunctionCodeDescriptor: ").Append(FunctionCodeDescriptor).Append("\n");
            sb.Append("  GrantCodeDescriptor: ").Append(GrantCodeDescriptor).Append("\n");
            sb.Append("  ObjectCodeDescriptor: ").Append(ObjectCodeDescriptor).Append("\n");
            sb.Append("  EducationOrganizationReference: ").Append(EducationOrganizationReference).Append("\n");
            sb.Append("  SchoolReference: ").Append(SchoolReference).Append("\n");
            sb.Append("  Amount: ").Append(Amount).Append("\n");
            sb.Append("  ExpenditureOtherOptional: ").Append(ExpenditureOtherOptional).Append("\n");
            sb.Append("  FundCodes: ").Append(FundCodes).Append("\n");
            sb.Append("  ProgramCodeDescriptor: ").Append(ProgramCodeDescriptor).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiExpenditure);
        }

        /// <summary>
        /// Returns true if MiExpenditure instances are equal
        /// </summary>
        /// <param name="input">Instance of MiExpenditure to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiExpenditure input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.FunctionCodeDescriptor == input.FunctionCodeDescriptor ||
                    (this.FunctionCodeDescriptor != null &&
                    this.FunctionCodeDescriptor.Equals(input.FunctionCodeDescriptor))
                ) && 
                (
                    this.GrantCodeDescriptor == input.GrantCodeDescriptor ||
                    (this.GrantCodeDescriptor != null &&
                    this.GrantCodeDescriptor.Equals(input.GrantCodeDescriptor))
                ) && 
                (
                    this.ObjectCodeDescriptor == input.ObjectCodeDescriptor ||
                    (this.ObjectCodeDescriptor != null &&
                    this.ObjectCodeDescriptor.Equals(input.ObjectCodeDescriptor))
                ) && 
                (
                    this.EducationOrganizationReference == input.EducationOrganizationReference ||
                    (this.EducationOrganizationReference != null &&
                    this.EducationOrganizationReference.Equals(input.EducationOrganizationReference))
                ) && 
                (
                    this.SchoolReference == input.SchoolReference ||
                    (this.SchoolReference != null &&
                    this.SchoolReference.Equals(input.SchoolReference))
                ) && 
                (
                    this.Amount == input.Amount ||
                    this.Amount.Equals(input.Amount)
                ) && 
                (
                    this.ExpenditureOtherOptional == input.ExpenditureOtherOptional ||
                    (this.ExpenditureOtherOptional != null &&
                    this.ExpenditureOtherOptional.Equals(input.ExpenditureOtherOptional))
                ) && 
                (
                    this.FundCodes == input.FundCodes ||
                    this.FundCodes != null &&
                    input.FundCodes != null &&
                    this.FundCodes.SequenceEqual(input.FundCodes)
                ) && 
                (
                    this.ProgramCodeDescriptor == input.ProgramCodeDescriptor ||
                    (this.ProgramCodeDescriptor != null &&
                    this.ProgramCodeDescriptor.Equals(input.ProgramCodeDescriptor))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                if (this.FunctionCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.FunctionCodeDescriptor.GetHashCode();
                }
                if (this.GrantCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.GrantCodeDescriptor.GetHashCode();
                }
                if (this.ObjectCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.ObjectCodeDescriptor.GetHashCode();
                }
                if (this.EducationOrganizationReference != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationReference.GetHashCode();
                }
                if (this.SchoolReference != null)
                {
                    hashCode = (hashCode * 59) + this.SchoolReference.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.Amount.GetHashCode();
                if (this.ExpenditureOtherOptional != null)
                {
                    hashCode = (hashCode * 59) + this.ExpenditureOtherOptional.GetHashCode();
                }
                if (this.FundCodes != null)
                {
                    hashCode = (hashCode * 59) + this.FundCodes.GetHashCode();
                }
                if (this.ProgramCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.ProgramCodeDescriptor.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // FunctionCodeDescriptor (string) maxLength
            if (this.FunctionCodeDescriptor != null && this.FunctionCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for FunctionCodeDescriptor, length must be less than 306.", new [] { "FunctionCodeDescriptor" });
            }

            // GrantCodeDescriptor (string) maxLength
            if (this.GrantCodeDescriptor != null && this.GrantCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for GrantCodeDescriptor, length must be less than 306.", new [] { "GrantCodeDescriptor" });
            }

            // ObjectCodeDescriptor (string) maxLength
            if (this.ObjectCodeDescriptor != null && this.ObjectCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ObjectCodeDescriptor, length must be less than 306.", new [] { "ObjectCodeDescriptor" });
            }

            // ExpenditureOtherOptional (string) maxLength
            if (this.ExpenditureOtherOptional != null && this.ExpenditureOtherOptional.Length > 4)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ExpenditureOtherOptional, length must be less than 4.", new [] { "ExpenditureOtherOptional" });
            }

            // ProgramCodeDescriptor (string) maxLength
            if (this.ProgramCodeDescriptor != null && this.ProgramCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ProgramCodeDescriptor, length must be less than 306.", new [] { "ProgramCodeDescriptor" });
            }

            yield break;
        }
    }

}
