/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiInterventionPrescriptionEffectiveness
    /// </summary>
    [DataContract(Name = "mi_interventionPrescriptionEffectiveness")]
    public partial class MiInterventionPrescriptionEffectiveness : IEquatable<MiInterventionPrescriptionEffectiveness>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiInterventionPrescriptionEffectiveness" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiInterventionPrescriptionEffectiveness() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiInterventionPrescriptionEffectiveness" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="effectivenessDate">Date Staff provided Effectiveness feedback. (required).</param>
        /// <param name="interventionPrescriptionReference">interventionPrescriptionReference (required).</param>
        /// <param name="staffReference">staffReference (required).</param>
        /// <param name="effectSize">Effectiveness factor..</param>
        /// <param name="fiveStar">Perception feedback, aggregated at district, isd, statewide, rated on student progress..</param>
        /// <param name="fiveStarComment">Narrative feedback associated with five star rating w/ assotication to person/email providing feedback..</param>
        /// <param name="growth">Growth - entered by teacher or assgned staff..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiInterventionPrescriptionEffectiveness(string id = default(string), DateTime effectivenessDate = default(DateTime), EdFiInterventionPrescriptionReference interventionPrescriptionReference = default(EdFiInterventionPrescriptionReference), EdFiStaffReference staffReference = default(EdFiStaffReference), double? effectSize = default(double?), int? fiveStar = default(int?), string fiveStarComment = default(string), double? growth = default(double?), string etag = default(string))
        {
            this.EffectivenessDate = effectivenessDate;
            // to ensure "interventionPrescriptionReference" is required (not null)
            if (interventionPrescriptionReference == null)
            {
                throw new ArgumentNullException("interventionPrescriptionReference is a required property for MiInterventionPrescriptionEffectiveness and cannot be null");
            }
            this.InterventionPrescriptionReference = interventionPrescriptionReference;
            // to ensure "staffReference" is required (not null)
            if (staffReference == null)
            {
                throw new ArgumentNullException("staffReference is a required property for MiInterventionPrescriptionEffectiveness and cannot be null");
            }
            this.StaffReference = staffReference;
            this.Id = id;
            this.EffectSize = effectSize;
            this.FiveStar = fiveStar;
            this.FiveStarComment = fiveStarComment;
            this.Growth = growth;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// Date Staff provided Effectiveness feedback.
        /// </summary>
        /// <value>Date Staff provided Effectiveness feedback.</value>
        [DataMember(Name = "effectivenessDate", IsRequired = true, EmitDefaultValue = false)]
        [JsonConverter(typeof(OpenAPIDateConverter))]
        public DateTime EffectivenessDate { get; set; }

        /// <summary>
        /// Gets or Sets InterventionPrescriptionReference
        /// </summary>
        [DataMember(Name = "interventionPrescriptionReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiInterventionPrescriptionReference InterventionPrescriptionReference { get; set; }

        /// <summary>
        /// Gets or Sets StaffReference
        /// </summary>
        [DataMember(Name = "staffReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiStaffReference StaffReference { get; set; }

        /// <summary>
        /// Effectiveness factor.
        /// </summary>
        /// <value>Effectiveness factor.</value>
        [DataMember(Name = "effectSize", EmitDefaultValue = true)]
        public double? EffectSize { get; set; }

        /// <summary>
        /// Perception feedback, aggregated at district, isd, statewide, rated on student progress.
        /// </summary>
        /// <value>Perception feedback, aggregated at district, isd, statewide, rated on student progress.</value>
        [DataMember(Name = "fiveStar", EmitDefaultValue = true)]
        public int? FiveStar { get; set; }

        /// <summary>
        /// Narrative feedback associated with five star rating w/ assotication to person/email providing feedback.
        /// </summary>
        /// <value>Narrative feedback associated with five star rating w/ assotication to person/email providing feedback.</value>
        [DataMember(Name = "fiveStarComment", EmitDefaultValue = true)]
        public string FiveStarComment { get; set; }

        /// <summary>
        /// Growth - entered by teacher or assgned staff.
        /// </summary>
        /// <value>Growth - entered by teacher or assgned staff.</value>
        [DataMember(Name = "growth", EmitDefaultValue = true)]
        public double? Growth { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiInterventionPrescriptionEffectiveness {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  EffectivenessDate: ").Append(EffectivenessDate).Append("\n");
            sb.Append("  InterventionPrescriptionReference: ").Append(InterventionPrescriptionReference).Append("\n");
            sb.Append("  StaffReference: ").Append(StaffReference).Append("\n");
            sb.Append("  EffectSize: ").Append(EffectSize).Append("\n");
            sb.Append("  FiveStar: ").Append(FiveStar).Append("\n");
            sb.Append("  FiveStarComment: ").Append(FiveStarComment).Append("\n");
            sb.Append("  Growth: ").Append(Growth).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiInterventionPrescriptionEffectiveness);
        }

        /// <summary>
        /// Returns true if MiInterventionPrescriptionEffectiveness instances are equal
        /// </summary>
        /// <param name="input">Instance of MiInterventionPrescriptionEffectiveness to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiInterventionPrescriptionEffectiveness input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.EffectivenessDate == input.EffectivenessDate ||
                    (this.EffectivenessDate != null &&
                    this.EffectivenessDate.Equals(input.EffectivenessDate))
                ) && 
                (
                    this.InterventionPrescriptionReference == input.InterventionPrescriptionReference ||
                    (this.InterventionPrescriptionReference != null &&
                    this.InterventionPrescriptionReference.Equals(input.InterventionPrescriptionReference))
                ) && 
                (
                    this.StaffReference == input.StaffReference ||
                    (this.StaffReference != null &&
                    this.StaffReference.Equals(input.StaffReference))
                ) && 
                (
                    this.EffectSize == input.EffectSize ||
                    (this.EffectSize != null &&
                    this.EffectSize.Equals(input.EffectSize))
                ) && 
                (
                    this.FiveStar == input.FiveStar ||
                    (this.FiveStar != null &&
                    this.FiveStar.Equals(input.FiveStar))
                ) && 
                (
                    this.FiveStarComment == input.FiveStarComment ||
                    (this.FiveStarComment != null &&
                    this.FiveStarComment.Equals(input.FiveStarComment))
                ) && 
                (
                    this.Growth == input.Growth ||
                    (this.Growth != null &&
                    this.Growth.Equals(input.Growth))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.EffectivenessDate != null)
                {
                    hashCode = (hashCode * 59) + this.EffectivenessDate.GetHashCode();
                }
                if (this.InterventionPrescriptionReference != null)
                {
                    hashCode = (hashCode * 59) + this.InterventionPrescriptionReference.GetHashCode();
                }
                if (this.StaffReference != null)
                {
                    hashCode = (hashCode * 59) + this.StaffReference.GetHashCode();
                }
                if (this.EffectSize != null)
                {
                    hashCode = (hashCode * 59) + this.EffectSize.GetHashCode();
                }
                if (this.FiveStar != null)
                {
                    hashCode = (hashCode * 59) + this.FiveStar.GetHashCode();
                }
                if (this.FiveStarComment != null)
                {
                    hashCode = (hashCode * 59) + this.FiveStarComment.GetHashCode();
                }
                if (this.Growth != null)
                {
                    hashCode = (hashCode * 59) + this.Growth.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // FiveStarComment (string) maxLength
            if (this.FiveStarComment != null && this.FiveStarComment.Length > 2048)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for FiveStarComment, length must be less than 2048.", new [] { "FiveStarComment" });
            }

            yield break;
        }
    }

}
