/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiLearningContentResource
    /// </summary>
    [DataContract(Name = "mi_learningContentResource")]
    public partial class MiLearningContentResource : IEquatable<MiLearningContentResource>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiLearningContentResource" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiLearningContentResource() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiLearningContentResource" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="title">Name of this resource. (required).</param>
        /// <param name="applicationId">Identifier of the application associated with this resource. This identifier is assigned by the creator/vendor of the resource..</param>
        /// <param name="importanceDescriptor">Indicates importance of the Resource (e.g., Primary, Secondary)..</param>
        /// <param name="statusDescriptor">Indicates the status of the Resource..</param>
        /// <param name="studentResource">0 &#x3D; is Student Resource1 &#x3D; is NOT Student Resource.</param>
        /// <param name="teacherResource">0 &#x3D; is NOT Teacher Resource1 &#x3D; is Teacher Resource.</param>
        /// <param name="vendorId">Identifier of the vendor responsible for this resource. This unique ID will be assigned by IMS during the OneRoster conformance process..</param>
        /// <param name="vendorResourceId">Unique ID of this resource as allocated by the vendor. It is unique in the context of resource identifiers allocated by the vendor..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiLearningContentResource(string id = default(string), string title = default(string), string applicationId = default(string), string importanceDescriptor = default(string), string statusDescriptor = default(string), bool? studentResource = default(bool?), bool? teacherResource = default(bool?), string vendorId = default(string), string vendorResourceId = default(string), string etag = default(string))
        {
            // to ensure "title" is required (not null)
            if (title == null)
            {
                throw new ArgumentNullException("title is a required property for MiLearningContentResource and cannot be null");
            }
            this.Title = title;
            this.Id = id;
            this.ApplicationId = applicationId;
            this.ImportanceDescriptor = importanceDescriptor;
            this.StatusDescriptor = statusDescriptor;
            this.StudentResource = studentResource;
            this.TeacherResource = teacherResource;
            this.VendorId = vendorId;
            this.VendorResourceId = vendorResourceId;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// Name of this resource.
        /// </summary>
        /// <value>Name of this resource.</value>
        [DataMember(Name = "title", IsRequired = true, EmitDefaultValue = false)]
        public string Title { get; set; }

        /// <summary>
        /// Identifier of the application associated with this resource. This identifier is assigned by the creator/vendor of the resource.
        /// </summary>
        /// <value>Identifier of the application associated with this resource. This identifier is assigned by the creator/vendor of the resource.</value>
        [DataMember(Name = "applicationId", EmitDefaultValue = true)]
        public string ApplicationId { get; set; }

        /// <summary>
        /// Indicates importance of the Resource (e.g., Primary, Secondary).
        /// </summary>
        /// <value>Indicates importance of the Resource (e.g., Primary, Secondary).</value>
        [DataMember(Name = "importanceDescriptor", EmitDefaultValue = true)]
        public string ImportanceDescriptor { get; set; }

        /// <summary>
        /// Indicates the status of the Resource.
        /// </summary>
        /// <value>Indicates the status of the Resource.</value>
        [DataMember(Name = "statusDescriptor", EmitDefaultValue = true)]
        public string StatusDescriptor { get; set; }

        /// <summary>
        /// 0 &#x3D; is Student Resource1 &#x3D; is NOT Student Resource
        /// </summary>
        /// <value>0 &#x3D; is Student Resource1 &#x3D; is NOT Student Resource</value>
        [DataMember(Name = "studentResource", EmitDefaultValue = true)]
        public bool? StudentResource { get; set; }

        /// <summary>
        /// 0 &#x3D; is NOT Teacher Resource1 &#x3D; is Teacher Resource
        /// </summary>
        /// <value>0 &#x3D; is NOT Teacher Resource1 &#x3D; is Teacher Resource</value>
        [DataMember(Name = "teacherResource", EmitDefaultValue = true)]
        public bool? TeacherResource { get; set; }

        /// <summary>
        /// Identifier of the vendor responsible for this resource. This unique ID will be assigned by IMS during the OneRoster conformance process.
        /// </summary>
        /// <value>Identifier of the vendor responsible for this resource. This unique ID will be assigned by IMS during the OneRoster conformance process.</value>
        [DataMember(Name = "vendorId", EmitDefaultValue = true)]
        public string VendorId { get; set; }

        /// <summary>
        /// Unique ID of this resource as allocated by the vendor. It is unique in the context of resource identifiers allocated by the vendor.
        /// </summary>
        /// <value>Unique ID of this resource as allocated by the vendor. It is unique in the context of resource identifiers allocated by the vendor.</value>
        [DataMember(Name = "vendorResourceId", EmitDefaultValue = true)]
        public string VendorResourceId { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiLearningContentResource {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  Title: ").Append(Title).Append("\n");
            sb.Append("  ApplicationId: ").Append(ApplicationId).Append("\n");
            sb.Append("  ImportanceDescriptor: ").Append(ImportanceDescriptor).Append("\n");
            sb.Append("  StatusDescriptor: ").Append(StatusDescriptor).Append("\n");
            sb.Append("  StudentResource: ").Append(StudentResource).Append("\n");
            sb.Append("  TeacherResource: ").Append(TeacherResource).Append("\n");
            sb.Append("  VendorId: ").Append(VendorId).Append("\n");
            sb.Append("  VendorResourceId: ").Append(VendorResourceId).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiLearningContentResource);
        }

        /// <summary>
        /// Returns true if MiLearningContentResource instances are equal
        /// </summary>
        /// <param name="input">Instance of MiLearningContentResource to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiLearningContentResource input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.Title == input.Title ||
                    (this.Title != null &&
                    this.Title.Equals(input.Title))
                ) && 
                (
                    this.ApplicationId == input.ApplicationId ||
                    (this.ApplicationId != null &&
                    this.ApplicationId.Equals(input.ApplicationId))
                ) && 
                (
                    this.ImportanceDescriptor == input.ImportanceDescriptor ||
                    (this.ImportanceDescriptor != null &&
                    this.ImportanceDescriptor.Equals(input.ImportanceDescriptor))
                ) && 
                (
                    this.StatusDescriptor == input.StatusDescriptor ||
                    (this.StatusDescriptor != null &&
                    this.StatusDescriptor.Equals(input.StatusDescriptor))
                ) && 
                (
                    this.StudentResource == input.StudentResource ||
                    (this.StudentResource != null &&
                    this.StudentResource.Equals(input.StudentResource))
                ) && 
                (
                    this.TeacherResource == input.TeacherResource ||
                    (this.TeacherResource != null &&
                    this.TeacherResource.Equals(input.TeacherResource))
                ) && 
                (
                    this.VendorId == input.VendorId ||
                    (this.VendorId != null &&
                    this.VendorId.Equals(input.VendorId))
                ) && 
                (
                    this.VendorResourceId == input.VendorResourceId ||
                    (this.VendorResourceId != null &&
                    this.VendorResourceId.Equals(input.VendorResourceId))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.Title != null)
                {
                    hashCode = (hashCode * 59) + this.Title.GetHashCode();
                }
                if (this.ApplicationId != null)
                {
                    hashCode = (hashCode * 59) + this.ApplicationId.GetHashCode();
                }
                if (this.ImportanceDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.ImportanceDescriptor.GetHashCode();
                }
                if (this.StatusDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.StatusDescriptor.GetHashCode();
                }
                if (this.StudentResource != null)
                {
                    hashCode = (hashCode * 59) + this.StudentResource.GetHashCode();
                }
                if (this.TeacherResource != null)
                {
                    hashCode = (hashCode * 59) + this.TeacherResource.GetHashCode();
                }
                if (this.VendorId != null)
                {
                    hashCode = (hashCode * 59) + this.VendorId.GetHashCode();
                }
                if (this.VendorResourceId != null)
                {
                    hashCode = (hashCode * 59) + this.VendorResourceId.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // Title (string) maxLength
            if (this.Title != null && this.Title.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for Title, length must be less than 75.", new [] { "Title" });
            }

            // ApplicationId (string) maxLength
            if (this.ApplicationId != null && this.ApplicationId.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ApplicationId, length must be less than 75.", new [] { "ApplicationId" });
            }

            // ImportanceDescriptor (string) maxLength
            if (this.ImportanceDescriptor != null && this.ImportanceDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ImportanceDescriptor, length must be less than 306.", new [] { "ImportanceDescriptor" });
            }

            // StatusDescriptor (string) maxLength
            if (this.StatusDescriptor != null && this.StatusDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for StatusDescriptor, length must be less than 306.", new [] { "StatusDescriptor" });
            }

            // VendorId (string) maxLength
            if (this.VendorId != null && this.VendorId.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for VendorId, length must be less than 75.", new [] { "VendorId" });
            }

            // VendorResourceId (string) maxLength
            if (this.VendorResourceId != null && this.VendorResourceId.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for VendorResourceId, length must be less than 75.", new [] { "VendorResourceId" });
            }

            yield break;
        }
    }

}
