/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiRevenue
    /// </summary>
    [DataContract(Name = "mi_revenue")]
    public partial class MiRevenue : IEquatable<MiRevenue>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiRevenue" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiRevenue() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiRevenue" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the revenue is submitted. (required).</param>
        /// <param name="revenueMajorClassDescriptor">The basic account identifier for recording transactions. (required).</param>
        /// <param name="educationOrganizationReference">educationOrganizationReference (required).</param>
        /// <param name="amount">Amount for the fund code / major class code submitted. (required).</param>
        /// <param name="fundCodes">An unordered collection of revenueFundCodes. The independent fisal and accounting entity for revenue transaction..</param>
        /// <param name="revenueOptional">An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection. (required).</param>
        /// <param name="revenueSuffixDescriptor">The code used to further define/distinguish between revenue sources. (required).</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiRevenue(string id = default(string), int fiscalYear = default(int), string revenueMajorClassDescriptor = default(string), EdFiEducationOrganizationReference educationOrganizationReference = default(EdFiEducationOrganizationReference), double amount = default(double), List<MiRevenueFundCode> fundCodes = default(List<MiRevenueFundCode>), string revenueOptional = default(string), string revenueSuffixDescriptor = default(string), string etag = default(string))
        {
            this.FiscalYear = fiscalYear;
            // to ensure "revenueMajorClassDescriptor" is required (not null)
            if (revenueMajorClassDescriptor == null)
            {
                throw new ArgumentNullException("revenueMajorClassDescriptor is a required property for MiRevenue and cannot be null");
            }
            this.RevenueMajorClassDescriptor = revenueMajorClassDescriptor;
            // to ensure "educationOrganizationReference" is required (not null)
            if (educationOrganizationReference == null)
            {
                throw new ArgumentNullException("educationOrganizationReference is a required property for MiRevenue and cannot be null");
            }
            this.EducationOrganizationReference = educationOrganizationReference;
            this.Amount = amount;
            // to ensure "revenueOptional" is required (not null)
            if (revenueOptional == null)
            {
                throw new ArgumentNullException("revenueOptional is a required property for MiRevenue and cannot be null");
            }
            this.RevenueOptional = revenueOptional;
            // to ensure "revenueSuffixDescriptor" is required (not null)
            if (revenueSuffixDescriptor == null)
            {
                throw new ArgumentNullException("revenueSuffixDescriptor is a required property for MiRevenue and cannot be null");
            }
            this.RevenueSuffixDescriptor = revenueSuffixDescriptor;
            this.Id = id;
            this.FundCodes = fundCodes;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the revenue is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the revenue is submitted.</value>
        [DataMember(Name = "fiscalYear", IsRequired = true, EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// The basic account identifier for recording transactions.
        /// </summary>
        /// <value>The basic account identifier for recording transactions.</value>
        [DataMember(Name = "revenueMajorClassDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string RevenueMajorClassDescriptor { get; set; }

        /// <summary>
        /// Gets or Sets EducationOrganizationReference
        /// </summary>
        [DataMember(Name = "educationOrganizationReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiEducationOrganizationReference EducationOrganizationReference { get; set; }

        /// <summary>
        /// Amount for the fund code / major class code submitted.
        /// </summary>
        /// <value>Amount for the fund code / major class code submitted.</value>
        [DataMember(Name = "amount", IsRequired = true, EmitDefaultValue = false)]
        public double Amount { get; set; }

        /// <summary>
        /// An unordered collection of revenueFundCodes. The independent fisal and accounting entity for revenue transaction.
        /// </summary>
        /// <value>An unordered collection of revenueFundCodes. The independent fisal and accounting entity for revenue transaction.</value>
        [DataMember(Name = "fundCodes", EmitDefaultValue = false)]
        public List<MiRevenueFundCode> FundCodes { get; set; }

        /// <summary>
        /// An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection.
        /// </summary>
        /// <value>An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection.</value>
        [DataMember(Name = "revenueOptional", IsRequired = true, EmitDefaultValue = false)]
        public string RevenueOptional { get; set; }

        /// <summary>
        /// The code used to further define/distinguish between revenue sources.
        /// </summary>
        /// <value>The code used to further define/distinguish between revenue sources.</value>
        [DataMember(Name = "revenueSuffixDescriptor", IsRequired = true, EmitDefaultValue = false)]
        public string RevenueSuffixDescriptor { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiRevenue {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  RevenueMajorClassDescriptor: ").Append(RevenueMajorClassDescriptor).Append("\n");
            sb.Append("  EducationOrganizationReference: ").Append(EducationOrganizationReference).Append("\n");
            sb.Append("  Amount: ").Append(Amount).Append("\n");
            sb.Append("  FundCodes: ").Append(FundCodes).Append("\n");
            sb.Append("  RevenueOptional: ").Append(RevenueOptional).Append("\n");
            sb.Append("  RevenueSuffixDescriptor: ").Append(RevenueSuffixDescriptor).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiRevenue);
        }

        /// <summary>
        /// Returns true if MiRevenue instances are equal
        /// </summary>
        /// <param name="input">Instance of MiRevenue to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiRevenue input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.RevenueMajorClassDescriptor == input.RevenueMajorClassDescriptor ||
                    (this.RevenueMajorClassDescriptor != null &&
                    this.RevenueMajorClassDescriptor.Equals(input.RevenueMajorClassDescriptor))
                ) && 
                (
                    this.EducationOrganizationReference == input.EducationOrganizationReference ||
                    (this.EducationOrganizationReference != null &&
                    this.EducationOrganizationReference.Equals(input.EducationOrganizationReference))
                ) && 
                (
                    this.Amount == input.Amount ||
                    this.Amount.Equals(input.Amount)
                ) && 
                (
                    this.FundCodes == input.FundCodes ||
                    this.FundCodes != null &&
                    input.FundCodes != null &&
                    this.FundCodes.SequenceEqual(input.FundCodes)
                ) && 
                (
                    this.RevenueOptional == input.RevenueOptional ||
                    (this.RevenueOptional != null &&
                    this.RevenueOptional.Equals(input.RevenueOptional))
                ) && 
                (
                    this.RevenueSuffixDescriptor == input.RevenueSuffixDescriptor ||
                    (this.RevenueSuffixDescriptor != null &&
                    this.RevenueSuffixDescriptor.Equals(input.RevenueSuffixDescriptor))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                if (this.RevenueMajorClassDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.RevenueMajorClassDescriptor.GetHashCode();
                }
                if (this.EducationOrganizationReference != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationReference.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.Amount.GetHashCode();
                if (this.FundCodes != null)
                {
                    hashCode = (hashCode * 59) + this.FundCodes.GetHashCode();
                }
                if (this.RevenueOptional != null)
                {
                    hashCode = (hashCode * 59) + this.RevenueOptional.GetHashCode();
                }
                if (this.RevenueSuffixDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.RevenueSuffixDescriptor.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // RevenueMajorClassDescriptor (string) maxLength
            if (this.RevenueMajorClassDescriptor != null && this.RevenueMajorClassDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for RevenueMajorClassDescriptor, length must be less than 306.", new [] { "RevenueMajorClassDescriptor" });
            }

            // RevenueOptional (string) maxLength
            if (this.RevenueOptional != null && this.RevenueOptional.Length > 16)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for RevenueOptional, length must be less than 16.", new [] { "RevenueOptional" });
            }

            // RevenueSuffixDescriptor (string) maxLength
            if (this.RevenueSuffixDescriptor != null && this.RevenueSuffixDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for RevenueSuffixDescriptor, length must be less than 306.", new [] { "RevenueSuffixDescriptor" });
            }

            yield break;
        }
    }

}
