/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiStudentAdultEducationProgramAssociation
    /// </summary>
    [DataContract(Name = "mi_studentAdultEducationProgramAssociation")]
    public partial class MiStudentAdultEducationProgramAssociation : IEquatable<MiStudentAdultEducationProgramAssociation>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiStudentAdultEducationProgramAssociation" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiStudentAdultEducationProgramAssociation() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiStudentAdultEducationProgramAssociation" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="beginDate">The earliest date the student is involved with the program. Typically, this is the date the student becomes eligible for the program. (required).</param>
        /// <param name="educationOrganizationReference">educationOrganizationReference (required).</param>
        /// <param name="programReference">programReference (required).</param>
        /// <param name="studentReference">studentReference (required).</param>
        /// <param name="adultEdCountPeriodDescriptor">The adult education reporting period during which the student participated in the program..</param>
        /// <param name="adultEdCountPeriodYear">The adult education reporting period year during which the student participated in the program.</param>
        /// <param name="adultEdFundingDescriptor">To indicate the funding source or sources through which the adult education program is provided..</param>
        /// <param name="eligibilityExceptionDescriptor">Indicates the exceptions made to allow program participation..</param>
        /// <param name="endDate">The month, day, and year on which the student exited the program or stopped receiving services..</param>
        /// <param name="enrollmentPercent">The full-time equivalency (FTE) that the participant spends in the adult education program reported..</param>
        /// <param name="participationStatus">participationStatus.</param>
        /// <param name="programParticipationStatuses">An unordered collection of generalStudentProgramAssociationProgramParticipationStatuses. The status of the student&#39;s program participation..</param>
        /// <param name="reasonExitedDescriptor">The reason the student left the program within a school or district..</param>
        /// <param name="servedOutsideOfRegularSession">Indicates whether the student received services during the summer session or between sessions..</param>
        /// <param name="services">An unordered collection of studentAdultEducationProgramAssociationServices. Indicates the Service(s) being provided to the Student by the Program..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiStudentAdultEducationProgramAssociation(string id = default(string), DateTime beginDate = default(DateTime), EdFiEducationOrganizationReference educationOrganizationReference = default(EdFiEducationOrganizationReference), EdFiProgramReference programReference = default(EdFiProgramReference), EdFiStudentReference studentReference = default(EdFiStudentReference), string adultEdCountPeriodDescriptor = default(string), int? adultEdCountPeriodYear = default(int?), string adultEdFundingDescriptor = default(string), string eligibilityExceptionDescriptor = default(string), DateTime? endDate = default(DateTime?), double? enrollmentPercent = default(double?), EdFiGeneralStudentProgramAssociationParticipationStatus participationStatus = default(EdFiGeneralStudentProgramAssociationParticipationStatus), List<EdFiGeneralStudentProgramAssociationProgramParticipationStatus> programParticipationStatuses = default(List<EdFiGeneralStudentProgramAssociationProgramParticipationStatus>), string reasonExitedDescriptor = default(string), bool? servedOutsideOfRegularSession = default(bool?), List<MiStudentAdultEducationProgramAssociationService> services = default(List<MiStudentAdultEducationProgramAssociationService>), string etag = default(string))
        {
            this.BeginDate = beginDate;
            // to ensure "educationOrganizationReference" is required (not null)
            if (educationOrganizationReference == null)
            {
                throw new ArgumentNullException("educationOrganizationReference is a required property for MiStudentAdultEducationProgramAssociation and cannot be null");
            }
            this.EducationOrganizationReference = educationOrganizationReference;
            // to ensure "programReference" is required (not null)
            if (programReference == null)
            {
                throw new ArgumentNullException("programReference is a required property for MiStudentAdultEducationProgramAssociation and cannot be null");
            }
            this.ProgramReference = programReference;
            // to ensure "studentReference" is required (not null)
            if (studentReference == null)
            {
                throw new ArgumentNullException("studentReference is a required property for MiStudentAdultEducationProgramAssociation and cannot be null");
            }
            this.StudentReference = studentReference;
            this.Id = id;
            this.AdultEdCountPeriodDescriptor = adultEdCountPeriodDescriptor;
            this.AdultEdCountPeriodYear = adultEdCountPeriodYear;
            this.AdultEdFundingDescriptor = adultEdFundingDescriptor;
            this.EligibilityExceptionDescriptor = eligibilityExceptionDescriptor;
            this.EndDate = endDate;
            this.EnrollmentPercent = enrollmentPercent;
            this.ParticipationStatus = participationStatus;
            this.ProgramParticipationStatuses = programParticipationStatuses;
            this.ReasonExitedDescriptor = reasonExitedDescriptor;
            this.ServedOutsideOfRegularSession = servedOutsideOfRegularSession;
            this.Services = services;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// The earliest date the student is involved with the program. Typically, this is the date the student becomes eligible for the program.
        /// </summary>
        /// <value>The earliest date the student is involved with the program. Typically, this is the date the student becomes eligible for the program.</value>
        [DataMember(Name = "beginDate", IsRequired = true, EmitDefaultValue = false)]
        [JsonConverter(typeof(OpenAPIDateConverter))]
        public DateTime BeginDate { get; set; }

        /// <summary>
        /// Gets or Sets EducationOrganizationReference
        /// </summary>
        [DataMember(Name = "educationOrganizationReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiEducationOrganizationReference EducationOrganizationReference { get; set; }

        /// <summary>
        /// Gets or Sets ProgramReference
        /// </summary>
        [DataMember(Name = "programReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiProgramReference ProgramReference { get; set; }

        /// <summary>
        /// Gets or Sets StudentReference
        /// </summary>
        [DataMember(Name = "studentReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiStudentReference StudentReference { get; set; }

        /// <summary>
        /// The adult education reporting period during which the student participated in the program.
        /// </summary>
        /// <value>The adult education reporting period during which the student participated in the program.</value>
        [DataMember(Name = "adultEdCountPeriodDescriptor", EmitDefaultValue = true)]
        public string AdultEdCountPeriodDescriptor { get; set; }

        /// <summary>
        /// The adult education reporting period year during which the student participated in the program
        /// </summary>
        /// <value>The adult education reporting period year during which the student participated in the program</value>
        [DataMember(Name = "adultEdCountPeriodYear", EmitDefaultValue = true)]
        public int? AdultEdCountPeriodYear { get; set; }

        /// <summary>
        /// To indicate the funding source or sources through which the adult education program is provided.
        /// </summary>
        /// <value>To indicate the funding source or sources through which the adult education program is provided.</value>
        [DataMember(Name = "adultEdFundingDescriptor", EmitDefaultValue = true)]
        public string AdultEdFundingDescriptor { get; set; }

        /// <summary>
        /// Indicates the exceptions made to allow program participation.
        /// </summary>
        /// <value>Indicates the exceptions made to allow program participation.</value>
        [DataMember(Name = "eligibilityExceptionDescriptor", EmitDefaultValue = true)]
        public string EligibilityExceptionDescriptor { get; set; }

        /// <summary>
        /// The month, day, and year on which the student exited the program or stopped receiving services.
        /// </summary>
        /// <value>The month, day, and year on which the student exited the program or stopped receiving services.</value>
        [DataMember(Name = "endDate", EmitDefaultValue = true)]
        [JsonConverter(typeof(OpenAPIDateConverter))]
        public DateTime? EndDate { get; set; }

        /// <summary>
        /// The full-time equivalency (FTE) that the participant spends in the adult education program reported.
        /// </summary>
        /// <value>The full-time equivalency (FTE) that the participant spends in the adult education program reported.</value>
        [DataMember(Name = "enrollmentPercent", EmitDefaultValue = true)]
        public double? EnrollmentPercent { get; set; }

        /// <summary>
        /// Gets or Sets ParticipationStatus
        /// </summary>
        [DataMember(Name = "participationStatus", EmitDefaultValue = false)]
        public EdFiGeneralStudentProgramAssociationParticipationStatus ParticipationStatus { get; set; }

        /// <summary>
        /// An unordered collection of generalStudentProgramAssociationProgramParticipationStatuses. The status of the student&#39;s program participation.
        /// </summary>
        /// <value>An unordered collection of generalStudentProgramAssociationProgramParticipationStatuses. The status of the student&#39;s program participation.</value>
        [DataMember(Name = "programParticipationStatuses", EmitDefaultValue = false)]
        public List<EdFiGeneralStudentProgramAssociationProgramParticipationStatus> ProgramParticipationStatuses { get; set; }

        /// <summary>
        /// The reason the student left the program within a school or district.
        /// </summary>
        /// <value>The reason the student left the program within a school or district.</value>
        [DataMember(Name = "reasonExitedDescriptor", EmitDefaultValue = true)]
        public string ReasonExitedDescriptor { get; set; }

        /// <summary>
        /// Indicates whether the student received services during the summer session or between sessions.
        /// </summary>
        /// <value>Indicates whether the student received services during the summer session or between sessions.</value>
        [DataMember(Name = "servedOutsideOfRegularSession", EmitDefaultValue = true)]
        public bool? ServedOutsideOfRegularSession { get; set; }

        /// <summary>
        /// An unordered collection of studentAdultEducationProgramAssociationServices. Indicates the Service(s) being provided to the Student by the Program.
        /// </summary>
        /// <value>An unordered collection of studentAdultEducationProgramAssociationServices. Indicates the Service(s) being provided to the Student by the Program.</value>
        [DataMember(Name = "services", EmitDefaultValue = false)]
        public List<MiStudentAdultEducationProgramAssociationService> Services { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiStudentAdultEducationProgramAssociation {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  BeginDate: ").Append(BeginDate).Append("\n");
            sb.Append("  EducationOrganizationReference: ").Append(EducationOrganizationReference).Append("\n");
            sb.Append("  ProgramReference: ").Append(ProgramReference).Append("\n");
            sb.Append("  StudentReference: ").Append(StudentReference).Append("\n");
            sb.Append("  AdultEdCountPeriodDescriptor: ").Append(AdultEdCountPeriodDescriptor).Append("\n");
            sb.Append("  AdultEdCountPeriodYear: ").Append(AdultEdCountPeriodYear).Append("\n");
            sb.Append("  AdultEdFundingDescriptor: ").Append(AdultEdFundingDescriptor).Append("\n");
            sb.Append("  EligibilityExceptionDescriptor: ").Append(EligibilityExceptionDescriptor).Append("\n");
            sb.Append("  EndDate: ").Append(EndDate).Append("\n");
            sb.Append("  EnrollmentPercent: ").Append(EnrollmentPercent).Append("\n");
            sb.Append("  ParticipationStatus: ").Append(ParticipationStatus).Append("\n");
            sb.Append("  ProgramParticipationStatuses: ").Append(ProgramParticipationStatuses).Append("\n");
            sb.Append("  ReasonExitedDescriptor: ").Append(ReasonExitedDescriptor).Append("\n");
            sb.Append("  ServedOutsideOfRegularSession: ").Append(ServedOutsideOfRegularSession).Append("\n");
            sb.Append("  Services: ").Append(Services).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiStudentAdultEducationProgramAssociation);
        }

        /// <summary>
        /// Returns true if MiStudentAdultEducationProgramAssociation instances are equal
        /// </summary>
        /// <param name="input">Instance of MiStudentAdultEducationProgramAssociation to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiStudentAdultEducationProgramAssociation input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.BeginDate == input.BeginDate ||
                    (this.BeginDate != null &&
                    this.BeginDate.Equals(input.BeginDate))
                ) && 
                (
                    this.EducationOrganizationReference == input.EducationOrganizationReference ||
                    (this.EducationOrganizationReference != null &&
                    this.EducationOrganizationReference.Equals(input.EducationOrganizationReference))
                ) && 
                (
                    this.ProgramReference == input.ProgramReference ||
                    (this.ProgramReference != null &&
                    this.ProgramReference.Equals(input.ProgramReference))
                ) && 
                (
                    this.StudentReference == input.StudentReference ||
                    (this.StudentReference != null &&
                    this.StudentReference.Equals(input.StudentReference))
                ) && 
                (
                    this.AdultEdCountPeriodDescriptor == input.AdultEdCountPeriodDescriptor ||
                    (this.AdultEdCountPeriodDescriptor != null &&
                    this.AdultEdCountPeriodDescriptor.Equals(input.AdultEdCountPeriodDescriptor))
                ) && 
                (
                    this.AdultEdCountPeriodYear == input.AdultEdCountPeriodYear ||
                    (this.AdultEdCountPeriodYear != null &&
                    this.AdultEdCountPeriodYear.Equals(input.AdultEdCountPeriodYear))
                ) && 
                (
                    this.AdultEdFundingDescriptor == input.AdultEdFundingDescriptor ||
                    (this.AdultEdFundingDescriptor != null &&
                    this.AdultEdFundingDescriptor.Equals(input.AdultEdFundingDescriptor))
                ) && 
                (
                    this.EligibilityExceptionDescriptor == input.EligibilityExceptionDescriptor ||
                    (this.EligibilityExceptionDescriptor != null &&
                    this.EligibilityExceptionDescriptor.Equals(input.EligibilityExceptionDescriptor))
                ) && 
                (
                    this.EndDate == input.EndDate ||
                    (this.EndDate != null &&
                    this.EndDate.Equals(input.EndDate))
                ) && 
                (
                    this.EnrollmentPercent == input.EnrollmentPercent ||
                    (this.EnrollmentPercent != null &&
                    this.EnrollmentPercent.Equals(input.EnrollmentPercent))
                ) && 
                (
                    this.ParticipationStatus == input.ParticipationStatus ||
                    (this.ParticipationStatus != null &&
                    this.ParticipationStatus.Equals(input.ParticipationStatus))
                ) && 
                (
                    this.ProgramParticipationStatuses == input.ProgramParticipationStatuses ||
                    this.ProgramParticipationStatuses != null &&
                    input.ProgramParticipationStatuses != null &&
                    this.ProgramParticipationStatuses.SequenceEqual(input.ProgramParticipationStatuses)
                ) && 
                (
                    this.ReasonExitedDescriptor == input.ReasonExitedDescriptor ||
                    (this.ReasonExitedDescriptor != null &&
                    this.ReasonExitedDescriptor.Equals(input.ReasonExitedDescriptor))
                ) && 
                (
                    this.ServedOutsideOfRegularSession == input.ServedOutsideOfRegularSession ||
                    (this.ServedOutsideOfRegularSession != null &&
                    this.ServedOutsideOfRegularSession.Equals(input.ServedOutsideOfRegularSession))
                ) && 
                (
                    this.Services == input.Services ||
                    this.Services != null &&
                    input.Services != null &&
                    this.Services.SequenceEqual(input.Services)
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.BeginDate != null)
                {
                    hashCode = (hashCode * 59) + this.BeginDate.GetHashCode();
                }
                if (this.EducationOrganizationReference != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationReference.GetHashCode();
                }
                if (this.ProgramReference != null)
                {
                    hashCode = (hashCode * 59) + this.ProgramReference.GetHashCode();
                }
                if (this.StudentReference != null)
                {
                    hashCode = (hashCode * 59) + this.StudentReference.GetHashCode();
                }
                if (this.AdultEdCountPeriodDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.AdultEdCountPeriodDescriptor.GetHashCode();
                }
                if (this.AdultEdCountPeriodYear != null)
                {
                    hashCode = (hashCode * 59) + this.AdultEdCountPeriodYear.GetHashCode();
                }
                if (this.AdultEdFundingDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.AdultEdFundingDescriptor.GetHashCode();
                }
                if (this.EligibilityExceptionDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EligibilityExceptionDescriptor.GetHashCode();
                }
                if (this.EndDate != null)
                {
                    hashCode = (hashCode * 59) + this.EndDate.GetHashCode();
                }
                if (this.EnrollmentPercent != null)
                {
                    hashCode = (hashCode * 59) + this.EnrollmentPercent.GetHashCode();
                }
                if (this.ParticipationStatus != null)
                {
                    hashCode = (hashCode * 59) + this.ParticipationStatus.GetHashCode();
                }
                if (this.ProgramParticipationStatuses != null)
                {
                    hashCode = (hashCode * 59) + this.ProgramParticipationStatuses.GetHashCode();
                }
                if (this.ReasonExitedDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.ReasonExitedDescriptor.GetHashCode();
                }
                if (this.ServedOutsideOfRegularSession != null)
                {
                    hashCode = (hashCode * 59) + this.ServedOutsideOfRegularSession.GetHashCode();
                }
                if (this.Services != null)
                {
                    hashCode = (hashCode * 59) + this.Services.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // AdultEdCountPeriodDescriptor (string) maxLength
            if (this.AdultEdCountPeriodDescriptor != null && this.AdultEdCountPeriodDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for AdultEdCountPeriodDescriptor, length must be less than 306.", new [] { "AdultEdCountPeriodDescriptor" });
            }

            // AdultEdFundingDescriptor (string) maxLength
            if (this.AdultEdFundingDescriptor != null && this.AdultEdFundingDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for AdultEdFundingDescriptor, length must be less than 306.", new [] { "AdultEdFundingDescriptor" });
            }

            // EligibilityExceptionDescriptor (string) maxLength
            if (this.EligibilityExceptionDescriptor != null && this.EligibilityExceptionDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EligibilityExceptionDescriptor, length must be less than 306.", new [] { "EligibilityExceptionDescriptor" });
            }

            // ReasonExitedDescriptor (string) maxLength
            if (this.ReasonExitedDescriptor != null && this.ReasonExitedDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ReasonExitedDescriptor, length must be less than 306.", new [] { "ReasonExitedDescriptor" });
            }

            yield break;
        }
    }

}
