/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiStudentAssessmentTimeOfTestingSnapshot
    /// </summary>
    [DataContract(Name = "mi_studentAssessmentTimeOfTestingSnapshot")]
    public partial class MiStudentAssessmentTimeOfTestingSnapshot : IEquatable<MiStudentAssessmentTimeOfTestingSnapshot>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiStudentAssessmentTimeOfTestingSnapshot" /> class.
        /// </summary>
        /// <param name="primaryDisabilityDescriptor">Primary Disability at the time of testing snapshot..</param>
        /// <param name="secondaryDisabilityDescriptor">Secondary Disability at the time of testing snapshot..</param>
        /// <param name="ethnicityDescriptor">Student Ethnicity from MSDS at the time of testing snapshot..</param>
        /// <param name="primaryLanguageDescriptor">Primary language of student - this is bubbled on answer document..</param>
        /// <param name="lepInstructionalProgramDescriptor">The primary type of English language acquistion program in which a student is currently enrolled.  Populated from MSDS at the time of testing..</param>
        /// <param name="buildingCode">5 digit Building Code from EEM at the time of the testing snapshot..</param>
        /// <param name="buildingName">Building Name from EEM at the time of the testing snapshot..</param>
        /// <param name="dateOfBirth">Student date of birth in YYYY-MM-DD format.</param>
        /// <param name="districtCode">5 digit District Code from EEM at the time of the testing snapshot..</param>
        /// <param name="districtName">District Name from EEM at the time of the testing snapshot..</param>
        /// <param name="economicallyDisadvantaged">1 digit identifier from MSDS at the time of testing:1 &#x3D; Y - Economically Disadvantaged0 &#x3D; N - Not Econmically Disadvantaged.</param>
        /// <param name="englishAcademicYears">Length of Time in LEP/ELL Program in a US school (regardless of country of origin) Valid values are 0-19. Represented in whole number of years by school year. Number of years that a student has been in a bilingual or ESOL program.  Round down: year and 10 months&#x3D;1  (A kindergarten student is always 0.)   Populated from bubbles on test..</param>
        /// <param name="englishLearner">1 digit identifier from MSDS at the time of testing1 &#x3D; Y - English Learner0 &#x3D; N - Not English Learner.</param>
        /// <param name="feederBuildingCode">5 digit Building Code from EEM where student received majority of instruction.</param>
        /// <param name="firstName">Student First Name from MSDS at the time of testing snapshot..</param>
        /// <param name="formerlyEnglishLearner">1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Formerly English Learner0 &#x3D; N - Not Formerly Learner.</param>
        /// <param name="fosterCare">Indicates if student is in foster care.1 &#x3D; Y - is in foster care 0 - N - is not in foster care.</param>
        /// <param name="gender">1 digit identifier from MSDS at the time of testingM - MaleF - Female.</param>
        /// <param name="homeless">1 digit identifier from MSDS or bubbled on test at the time of testing1 &#x3D; Y - Homeless0 &#x3D; N - Not Homeless Homeless.</param>
        /// <param name="homeSchool">1 digit identifier from MSDS or bubbled on test at the time of testing1 &#x3D; Y - Home School0 &#x3D; N - Not Home School.</param>
        /// <param name="isdCode">5 digit ISDCode from EEM at the time of the testing snapshot..</param>
        /// <param name="isdName">ISDName from EEM at the time of the testing snapshot.</param>
        /// <param name="knowledgeOfIEP">1 &#x3D; Y - Knowledge Of IEP for student0 &#x3D; N - Does not have knowledge of IEP for studentblankPopulated from bubbles on test..</param>
        /// <param name="lastSurname">Student Last Name from MSDS at the time of testing snapshot..</param>
        /// <param name="liepOptionalData">Space for up to 3, 3-letter codes for more specific program identifiers.</param>
        /// <param name="liepParentRefusal">Indicates if the student&#39;s parent has refused language services1 &#x3D; Y - Parent Refusal0 &#x3D; N - No parent Refusal.</param>
        /// <param name="ltfay">1 digit identifier that indicates if a student was less than full academic year at the building where tested.1 &#x3D; Y - Less than Full Academic Year0 &#x3D; N - Full Academic Year.</param>
        /// <param name="middleName">Student Middle Name from MSDS at the time of testing snapshot..</param>
        /// <param name="migrant">1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Migrant0 &#x3D; N - Not Migrant Migrant.</param>
        /// <param name="militaryConnected">Indicates if student is military connected.1 &#x3D; Y - is military connected0 &#x3D; N - is not military connected.</param>
        /// <param name="privateIndicator">1 &#x3D; Y - Private School0 &#x3D; N - Public School.</param>
        /// <param name="specialEducation">1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Special Education0 &#x3D; N - Not Special Education.</param>
        /// <param name="studentIDNumber">District assigned ID number for a student from MSDS at the time of testing snapshot..</param>
        /// <param name="yearsSchoolingUS">Number of years schooling in US.</param>
        public MiStudentAssessmentTimeOfTestingSnapshot(string primaryDisabilityDescriptor = default(string), string secondaryDisabilityDescriptor = default(string), string ethnicityDescriptor = default(string), string primaryLanguageDescriptor = default(string), string lepInstructionalProgramDescriptor = default(string), string buildingCode = default(string), string buildingName = default(string), DateTime? dateOfBirth = default(DateTime?), string districtCode = default(string), string districtName = default(string), bool? economicallyDisadvantaged = default(bool?), string englishAcademicYears = default(string), bool? englishLearner = default(bool?), string feederBuildingCode = default(string), string firstName = default(string), bool? formerlyEnglishLearner = default(bool?), bool? fosterCare = default(bool?), string gender = default(string), bool? homeless = default(bool?), bool? homeSchool = default(bool?), string isdCode = default(string), string isdName = default(string), bool? knowledgeOfIEP = default(bool?), string lastSurname = default(string), string liepOptionalData = default(string), bool? liepParentRefusal = default(bool?), bool? ltfay = default(bool?), string middleName = default(string), bool? migrant = default(bool?), bool? militaryConnected = default(bool?), bool? privateIndicator = default(bool?), bool? specialEducation = default(bool?), string studentIDNumber = default(string), int? yearsSchoolingUS = default(int?))
        {
            this.PrimaryDisabilityDescriptor = primaryDisabilityDescriptor;
            this.SecondaryDisabilityDescriptor = secondaryDisabilityDescriptor;
            this.EthnicityDescriptor = ethnicityDescriptor;
            this.PrimaryLanguageDescriptor = primaryLanguageDescriptor;
            this.LepInstructionalProgramDescriptor = lepInstructionalProgramDescriptor;
            this.BuildingCode = buildingCode;
            this.BuildingName = buildingName;
            this.DateOfBirth = dateOfBirth;
            this.DistrictCode = districtCode;
            this.DistrictName = districtName;
            this.EconomicallyDisadvantaged = economicallyDisadvantaged;
            this.EnglishAcademicYears = englishAcademicYears;
            this.EnglishLearner = englishLearner;
            this.FeederBuildingCode = feederBuildingCode;
            this.FirstName = firstName;
            this.FormerlyEnglishLearner = formerlyEnglishLearner;
            this.FosterCare = fosterCare;
            this.Gender = gender;
            this.Homeless = homeless;
            this.HomeSchool = homeSchool;
            this.IsdCode = isdCode;
            this.IsdName = isdName;
            this.KnowledgeOfIEP = knowledgeOfIEP;
            this.LastSurname = lastSurname;
            this.LiepOptionalData = liepOptionalData;
            this.LiepParentRefusal = liepParentRefusal;
            this.Ltfay = ltfay;
            this.MiddleName = middleName;
            this.Migrant = migrant;
            this.MilitaryConnected = militaryConnected;
            this.PrivateIndicator = privateIndicator;
            this.SpecialEducation = specialEducation;
            this.StudentIDNumber = studentIDNumber;
            this.YearsSchoolingUS = yearsSchoolingUS;
        }

        /// <summary>
        /// Primary Disability at the time of testing snapshot.
        /// </summary>
        /// <value>Primary Disability at the time of testing snapshot.</value>
        [DataMember(Name = "primaryDisabilityDescriptor", EmitDefaultValue = true)]
        public string PrimaryDisabilityDescriptor { get; set; }

        /// <summary>
        /// Secondary Disability at the time of testing snapshot.
        /// </summary>
        /// <value>Secondary Disability at the time of testing snapshot.</value>
        [DataMember(Name = "secondaryDisabilityDescriptor", EmitDefaultValue = true)]
        public string SecondaryDisabilityDescriptor { get; set; }

        /// <summary>
        /// Student Ethnicity from MSDS at the time of testing snapshot.
        /// </summary>
        /// <value>Student Ethnicity from MSDS at the time of testing snapshot.</value>
        [DataMember(Name = "ethnicityDescriptor", EmitDefaultValue = true)]
        public string EthnicityDescriptor { get; set; }

        /// <summary>
        /// Primary language of student - this is bubbled on answer document.
        /// </summary>
        /// <value>Primary language of student - this is bubbled on answer document.</value>
        [DataMember(Name = "primaryLanguageDescriptor", EmitDefaultValue = true)]
        public string PrimaryLanguageDescriptor { get; set; }

        /// <summary>
        /// The primary type of English language acquistion program in which a student is currently enrolled.  Populated from MSDS at the time of testing.
        /// </summary>
        /// <value>The primary type of English language acquistion program in which a student is currently enrolled.  Populated from MSDS at the time of testing.</value>
        [DataMember(Name = "lepInstructionalProgramDescriptor", EmitDefaultValue = true)]
        public string LepInstructionalProgramDescriptor { get; set; }

        /// <summary>
        /// 5 digit Building Code from EEM at the time of the testing snapshot.
        /// </summary>
        /// <value>5 digit Building Code from EEM at the time of the testing snapshot.</value>
        [DataMember(Name = "buildingCode", EmitDefaultValue = true)]
        public string BuildingCode { get; set; }

        /// <summary>
        /// Building Name from EEM at the time of the testing snapshot.
        /// </summary>
        /// <value>Building Name from EEM at the time of the testing snapshot.</value>
        [DataMember(Name = "buildingName", EmitDefaultValue = true)]
        public string BuildingName { get; set; }

        /// <summary>
        /// Student date of birth in YYYY-MM-DD format
        /// </summary>
        /// <value>Student date of birth in YYYY-MM-DD format</value>
        [DataMember(Name = "dateOfBirth", EmitDefaultValue = true)]
        [JsonConverter(typeof(OpenAPIDateConverter))]
        public DateTime? DateOfBirth { get; set; }

        /// <summary>
        /// 5 digit District Code from EEM at the time of the testing snapshot.
        /// </summary>
        /// <value>5 digit District Code from EEM at the time of the testing snapshot.</value>
        [DataMember(Name = "districtCode", EmitDefaultValue = true)]
        public string DistrictCode { get; set; }

        /// <summary>
        /// District Name from EEM at the time of the testing snapshot.
        /// </summary>
        /// <value>District Name from EEM at the time of the testing snapshot.</value>
        [DataMember(Name = "districtName", EmitDefaultValue = true)]
        public string DistrictName { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS at the time of testing:1 &#x3D; Y - Economically Disadvantaged0 &#x3D; N - Not Econmically Disadvantaged
        /// </summary>
        /// <value>1 digit identifier from MSDS at the time of testing:1 &#x3D; Y - Economically Disadvantaged0 &#x3D; N - Not Econmically Disadvantaged</value>
        [DataMember(Name = "economicallyDisadvantaged", EmitDefaultValue = true)]
        public bool? EconomicallyDisadvantaged { get; set; }

        /// <summary>
        /// Length of Time in LEP/ELL Program in a US school (regardless of country of origin) Valid values are 0-19. Represented in whole number of years by school year. Number of years that a student has been in a bilingual or ESOL program.  Round down: year and 10 months&#x3D;1  (A kindergarten student is always 0.)   Populated from bubbles on test.
        /// </summary>
        /// <value>Length of Time in LEP/ELL Program in a US school (regardless of country of origin) Valid values are 0-19. Represented in whole number of years by school year. Number of years that a student has been in a bilingual or ESOL program.  Round down: year and 10 months&#x3D;1  (A kindergarten student is always 0.)   Populated from bubbles on test.</value>
        [DataMember(Name = "englishAcademicYears", EmitDefaultValue = true)]
        public string EnglishAcademicYears { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS at the time of testing1 &#x3D; Y - English Learner0 &#x3D; N - Not English Learner
        /// </summary>
        /// <value>1 digit identifier from MSDS at the time of testing1 &#x3D; Y - English Learner0 &#x3D; N - Not English Learner</value>
        [DataMember(Name = "englishLearner", EmitDefaultValue = true)]
        public bool? EnglishLearner { get; set; }

        /// <summary>
        /// 5 digit Building Code from EEM where student received majority of instruction
        /// </summary>
        /// <value>5 digit Building Code from EEM where student received majority of instruction</value>
        [DataMember(Name = "feederBuildingCode", EmitDefaultValue = true)]
        public string FeederBuildingCode { get; set; }

        /// <summary>
        /// Student First Name from MSDS at the time of testing snapshot.
        /// </summary>
        /// <value>Student First Name from MSDS at the time of testing snapshot.</value>
        [DataMember(Name = "firstName", EmitDefaultValue = true)]
        public string FirstName { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Formerly English Learner0 &#x3D; N - Not Formerly Learner
        /// </summary>
        /// <value>1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Formerly English Learner0 &#x3D; N - Not Formerly Learner</value>
        [DataMember(Name = "formerlyEnglishLearner", EmitDefaultValue = true)]
        public bool? FormerlyEnglishLearner { get; set; }

        /// <summary>
        /// Indicates if student is in foster care.1 &#x3D; Y - is in foster care 0 - N - is not in foster care
        /// </summary>
        /// <value>Indicates if student is in foster care.1 &#x3D; Y - is in foster care 0 - N - is not in foster care</value>
        [DataMember(Name = "fosterCare", EmitDefaultValue = true)]
        public bool? FosterCare { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS at the time of testingM - MaleF - Female
        /// </summary>
        /// <value>1 digit identifier from MSDS at the time of testingM - MaleF - Female</value>
        [DataMember(Name = "gender", EmitDefaultValue = true)]
        public string Gender { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS or bubbled on test at the time of testing1 &#x3D; Y - Homeless0 &#x3D; N - Not Homeless Homeless
        /// </summary>
        /// <value>1 digit identifier from MSDS or bubbled on test at the time of testing1 &#x3D; Y - Homeless0 &#x3D; N - Not Homeless Homeless</value>
        [DataMember(Name = "homeless", EmitDefaultValue = true)]
        public bool? Homeless { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS or bubbled on test at the time of testing1 &#x3D; Y - Home School0 &#x3D; N - Not Home School
        /// </summary>
        /// <value>1 digit identifier from MSDS or bubbled on test at the time of testing1 &#x3D; Y - Home School0 &#x3D; N - Not Home School</value>
        [DataMember(Name = "homeSchool", EmitDefaultValue = true)]
        public bool? HomeSchool { get; set; }

        /// <summary>
        /// 5 digit ISDCode from EEM at the time of the testing snapshot.
        /// </summary>
        /// <value>5 digit ISDCode from EEM at the time of the testing snapshot.</value>
        [DataMember(Name = "isdCode", EmitDefaultValue = true)]
        public string IsdCode { get; set; }

        /// <summary>
        /// ISDName from EEM at the time of the testing snapshot
        /// </summary>
        /// <value>ISDName from EEM at the time of the testing snapshot</value>
        [DataMember(Name = "isdName", EmitDefaultValue = true)]
        public string IsdName { get; set; }

        /// <summary>
        /// 1 &#x3D; Y - Knowledge Of IEP for student0 &#x3D; N - Does not have knowledge of IEP for studentblankPopulated from bubbles on test.
        /// </summary>
        /// <value>1 &#x3D; Y - Knowledge Of IEP for student0 &#x3D; N - Does not have knowledge of IEP for studentblankPopulated from bubbles on test.</value>
        [DataMember(Name = "knowledgeOfIEP", EmitDefaultValue = true)]
        public bool? KnowledgeOfIEP { get; set; }

        /// <summary>
        /// Student Last Name from MSDS at the time of testing snapshot.
        /// </summary>
        /// <value>Student Last Name from MSDS at the time of testing snapshot.</value>
        [DataMember(Name = "lastSurname", EmitDefaultValue = true)]
        public string LastSurname { get; set; }

        /// <summary>
        /// Space for up to 3, 3-letter codes for more specific program identifiers
        /// </summary>
        /// <value>Space for up to 3, 3-letter codes for more specific program identifiers</value>
        [DataMember(Name = "liepOptionalData", EmitDefaultValue = true)]
        public string LiepOptionalData { get; set; }

        /// <summary>
        /// Indicates if the student&#39;s parent has refused language services1 &#x3D; Y - Parent Refusal0 &#x3D; N - No parent Refusal
        /// </summary>
        /// <value>Indicates if the student&#39;s parent has refused language services1 &#x3D; Y - Parent Refusal0 &#x3D; N - No parent Refusal</value>
        [DataMember(Name = "liepParentRefusal", EmitDefaultValue = true)]
        public bool? LiepParentRefusal { get; set; }

        /// <summary>
        /// 1 digit identifier that indicates if a student was less than full academic year at the building where tested.1 &#x3D; Y - Less than Full Academic Year0 &#x3D; N - Full Academic Year
        /// </summary>
        /// <value>1 digit identifier that indicates if a student was less than full academic year at the building where tested.1 &#x3D; Y - Less than Full Academic Year0 &#x3D; N - Full Academic Year</value>
        [DataMember(Name = "ltfay", EmitDefaultValue = true)]
        public bool? Ltfay { get; set; }

        /// <summary>
        /// Student Middle Name from MSDS at the time of testing snapshot.
        /// </summary>
        /// <value>Student Middle Name from MSDS at the time of testing snapshot.</value>
        [DataMember(Name = "middleName", EmitDefaultValue = true)]
        public string MiddleName { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Migrant0 &#x3D; N - Not Migrant Migrant
        /// </summary>
        /// <value>1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Migrant0 &#x3D; N - Not Migrant Migrant</value>
        [DataMember(Name = "migrant", EmitDefaultValue = true)]
        public bool? Migrant { get; set; }

        /// <summary>
        /// Indicates if student is military connected.1 &#x3D; Y - is military connected0 &#x3D; N - is not military connected
        /// </summary>
        /// <value>Indicates if student is military connected.1 &#x3D; Y - is military connected0 &#x3D; N - is not military connected</value>
        [DataMember(Name = "militaryConnected", EmitDefaultValue = true)]
        public bool? MilitaryConnected { get; set; }

        /// <summary>
        /// 1 &#x3D; Y - Private School0 &#x3D; N - Public School
        /// </summary>
        /// <value>1 &#x3D; Y - Private School0 &#x3D; N - Public School</value>
        [DataMember(Name = "privateIndicator", EmitDefaultValue = true)]
        public bool? PrivateIndicator { get; set; }

        /// <summary>
        /// 1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Special Education0 &#x3D; N - Not Special Education
        /// </summary>
        /// <value>1 digit identifier from MSDS at the time of testing1 &#x3D; Y - Special Education0 &#x3D; N - Not Special Education</value>
        [DataMember(Name = "specialEducation", EmitDefaultValue = true)]
        public bool? SpecialEducation { get; set; }

        /// <summary>
        /// District assigned ID number for a student from MSDS at the time of testing snapshot.
        /// </summary>
        /// <value>District assigned ID number for a student from MSDS at the time of testing snapshot.</value>
        [DataMember(Name = "studentIDNumber", EmitDefaultValue = true)]
        public string StudentIDNumber { get; set; }

        /// <summary>
        /// Number of years schooling in US
        /// </summary>
        /// <value>Number of years schooling in US</value>
        [DataMember(Name = "yearsSchoolingUS", EmitDefaultValue = true)]
        public int? YearsSchoolingUS { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiStudentAssessmentTimeOfTestingSnapshot {\n");
            sb.Append("  PrimaryDisabilityDescriptor: ").Append(PrimaryDisabilityDescriptor).Append("\n");
            sb.Append("  SecondaryDisabilityDescriptor: ").Append(SecondaryDisabilityDescriptor).Append("\n");
            sb.Append("  EthnicityDescriptor: ").Append(EthnicityDescriptor).Append("\n");
            sb.Append("  PrimaryLanguageDescriptor: ").Append(PrimaryLanguageDescriptor).Append("\n");
            sb.Append("  LepInstructionalProgramDescriptor: ").Append(LepInstructionalProgramDescriptor).Append("\n");
            sb.Append("  BuildingCode: ").Append(BuildingCode).Append("\n");
            sb.Append("  BuildingName: ").Append(BuildingName).Append("\n");
            sb.Append("  DateOfBirth: ").Append(DateOfBirth).Append("\n");
            sb.Append("  DistrictCode: ").Append(DistrictCode).Append("\n");
            sb.Append("  DistrictName: ").Append(DistrictName).Append("\n");
            sb.Append("  EconomicallyDisadvantaged: ").Append(EconomicallyDisadvantaged).Append("\n");
            sb.Append("  EnglishAcademicYears: ").Append(EnglishAcademicYears).Append("\n");
            sb.Append("  EnglishLearner: ").Append(EnglishLearner).Append("\n");
            sb.Append("  FeederBuildingCode: ").Append(FeederBuildingCode).Append("\n");
            sb.Append("  FirstName: ").Append(FirstName).Append("\n");
            sb.Append("  FormerlyEnglishLearner: ").Append(FormerlyEnglishLearner).Append("\n");
            sb.Append("  FosterCare: ").Append(FosterCare).Append("\n");
            sb.Append("  Gender: ").Append(Gender).Append("\n");
            sb.Append("  Homeless: ").Append(Homeless).Append("\n");
            sb.Append("  HomeSchool: ").Append(HomeSchool).Append("\n");
            sb.Append("  IsdCode: ").Append(IsdCode).Append("\n");
            sb.Append("  IsdName: ").Append(IsdName).Append("\n");
            sb.Append("  KnowledgeOfIEP: ").Append(KnowledgeOfIEP).Append("\n");
            sb.Append("  LastSurname: ").Append(LastSurname).Append("\n");
            sb.Append("  LiepOptionalData: ").Append(LiepOptionalData).Append("\n");
            sb.Append("  LiepParentRefusal: ").Append(LiepParentRefusal).Append("\n");
            sb.Append("  Ltfay: ").Append(Ltfay).Append("\n");
            sb.Append("  MiddleName: ").Append(MiddleName).Append("\n");
            sb.Append("  Migrant: ").Append(Migrant).Append("\n");
            sb.Append("  MilitaryConnected: ").Append(MilitaryConnected).Append("\n");
            sb.Append("  PrivateIndicator: ").Append(PrivateIndicator).Append("\n");
            sb.Append("  SpecialEducation: ").Append(SpecialEducation).Append("\n");
            sb.Append("  StudentIDNumber: ").Append(StudentIDNumber).Append("\n");
            sb.Append("  YearsSchoolingUS: ").Append(YearsSchoolingUS).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiStudentAssessmentTimeOfTestingSnapshot);
        }

        /// <summary>
        /// Returns true if MiStudentAssessmentTimeOfTestingSnapshot instances are equal
        /// </summary>
        /// <param name="input">Instance of MiStudentAssessmentTimeOfTestingSnapshot to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiStudentAssessmentTimeOfTestingSnapshot input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.PrimaryDisabilityDescriptor == input.PrimaryDisabilityDescriptor ||
                    (this.PrimaryDisabilityDescriptor != null &&
                    this.PrimaryDisabilityDescriptor.Equals(input.PrimaryDisabilityDescriptor))
                ) && 
                (
                    this.SecondaryDisabilityDescriptor == input.SecondaryDisabilityDescriptor ||
                    (this.SecondaryDisabilityDescriptor != null &&
                    this.SecondaryDisabilityDescriptor.Equals(input.SecondaryDisabilityDescriptor))
                ) && 
                (
                    this.EthnicityDescriptor == input.EthnicityDescriptor ||
                    (this.EthnicityDescriptor != null &&
                    this.EthnicityDescriptor.Equals(input.EthnicityDescriptor))
                ) && 
                (
                    this.PrimaryLanguageDescriptor == input.PrimaryLanguageDescriptor ||
                    (this.PrimaryLanguageDescriptor != null &&
                    this.PrimaryLanguageDescriptor.Equals(input.PrimaryLanguageDescriptor))
                ) && 
                (
                    this.LepInstructionalProgramDescriptor == input.LepInstructionalProgramDescriptor ||
                    (this.LepInstructionalProgramDescriptor != null &&
                    this.LepInstructionalProgramDescriptor.Equals(input.LepInstructionalProgramDescriptor))
                ) && 
                (
                    this.BuildingCode == input.BuildingCode ||
                    (this.BuildingCode != null &&
                    this.BuildingCode.Equals(input.BuildingCode))
                ) && 
                (
                    this.BuildingName == input.BuildingName ||
                    (this.BuildingName != null &&
                    this.BuildingName.Equals(input.BuildingName))
                ) && 
                (
                    this.DateOfBirth == input.DateOfBirth ||
                    (this.DateOfBirth != null &&
                    this.DateOfBirth.Equals(input.DateOfBirth))
                ) && 
                (
                    this.DistrictCode == input.DistrictCode ||
                    (this.DistrictCode != null &&
                    this.DistrictCode.Equals(input.DistrictCode))
                ) && 
                (
                    this.DistrictName == input.DistrictName ||
                    (this.DistrictName != null &&
                    this.DistrictName.Equals(input.DistrictName))
                ) && 
                (
                    this.EconomicallyDisadvantaged == input.EconomicallyDisadvantaged ||
                    (this.EconomicallyDisadvantaged != null &&
                    this.EconomicallyDisadvantaged.Equals(input.EconomicallyDisadvantaged))
                ) && 
                (
                    this.EnglishAcademicYears == input.EnglishAcademicYears ||
                    (this.EnglishAcademicYears != null &&
                    this.EnglishAcademicYears.Equals(input.EnglishAcademicYears))
                ) && 
                (
                    this.EnglishLearner == input.EnglishLearner ||
                    (this.EnglishLearner != null &&
                    this.EnglishLearner.Equals(input.EnglishLearner))
                ) && 
                (
                    this.FeederBuildingCode == input.FeederBuildingCode ||
                    (this.FeederBuildingCode != null &&
                    this.FeederBuildingCode.Equals(input.FeederBuildingCode))
                ) && 
                (
                    this.FirstName == input.FirstName ||
                    (this.FirstName != null &&
                    this.FirstName.Equals(input.FirstName))
                ) && 
                (
                    this.FormerlyEnglishLearner == input.FormerlyEnglishLearner ||
                    (this.FormerlyEnglishLearner != null &&
                    this.FormerlyEnglishLearner.Equals(input.FormerlyEnglishLearner))
                ) && 
                (
                    this.FosterCare == input.FosterCare ||
                    (this.FosterCare != null &&
                    this.FosterCare.Equals(input.FosterCare))
                ) && 
                (
                    this.Gender == input.Gender ||
                    (this.Gender != null &&
                    this.Gender.Equals(input.Gender))
                ) && 
                (
                    this.Homeless == input.Homeless ||
                    (this.Homeless != null &&
                    this.Homeless.Equals(input.Homeless))
                ) && 
                (
                    this.HomeSchool == input.HomeSchool ||
                    (this.HomeSchool != null &&
                    this.HomeSchool.Equals(input.HomeSchool))
                ) && 
                (
                    this.IsdCode == input.IsdCode ||
                    (this.IsdCode != null &&
                    this.IsdCode.Equals(input.IsdCode))
                ) && 
                (
                    this.IsdName == input.IsdName ||
                    (this.IsdName != null &&
                    this.IsdName.Equals(input.IsdName))
                ) && 
                (
                    this.KnowledgeOfIEP == input.KnowledgeOfIEP ||
                    (this.KnowledgeOfIEP != null &&
                    this.KnowledgeOfIEP.Equals(input.KnowledgeOfIEP))
                ) && 
                (
                    this.LastSurname == input.LastSurname ||
                    (this.LastSurname != null &&
                    this.LastSurname.Equals(input.LastSurname))
                ) && 
                (
                    this.LiepOptionalData == input.LiepOptionalData ||
                    (this.LiepOptionalData != null &&
                    this.LiepOptionalData.Equals(input.LiepOptionalData))
                ) && 
                (
                    this.LiepParentRefusal == input.LiepParentRefusal ||
                    (this.LiepParentRefusal != null &&
                    this.LiepParentRefusal.Equals(input.LiepParentRefusal))
                ) && 
                (
                    this.Ltfay == input.Ltfay ||
                    (this.Ltfay != null &&
                    this.Ltfay.Equals(input.Ltfay))
                ) && 
                (
                    this.MiddleName == input.MiddleName ||
                    (this.MiddleName != null &&
                    this.MiddleName.Equals(input.MiddleName))
                ) && 
                (
                    this.Migrant == input.Migrant ||
                    (this.Migrant != null &&
                    this.Migrant.Equals(input.Migrant))
                ) && 
                (
                    this.MilitaryConnected == input.MilitaryConnected ||
                    (this.MilitaryConnected != null &&
                    this.MilitaryConnected.Equals(input.MilitaryConnected))
                ) && 
                (
                    this.PrivateIndicator == input.PrivateIndicator ||
                    (this.PrivateIndicator != null &&
                    this.PrivateIndicator.Equals(input.PrivateIndicator))
                ) && 
                (
                    this.SpecialEducation == input.SpecialEducation ||
                    (this.SpecialEducation != null &&
                    this.SpecialEducation.Equals(input.SpecialEducation))
                ) && 
                (
                    this.StudentIDNumber == input.StudentIDNumber ||
                    (this.StudentIDNumber != null &&
                    this.StudentIDNumber.Equals(input.StudentIDNumber))
                ) && 
                (
                    this.YearsSchoolingUS == input.YearsSchoolingUS ||
                    (this.YearsSchoolingUS != null &&
                    this.YearsSchoolingUS.Equals(input.YearsSchoolingUS))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.PrimaryDisabilityDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.PrimaryDisabilityDescriptor.GetHashCode();
                }
                if (this.SecondaryDisabilityDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.SecondaryDisabilityDescriptor.GetHashCode();
                }
                if (this.EthnicityDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EthnicityDescriptor.GetHashCode();
                }
                if (this.PrimaryLanguageDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.PrimaryLanguageDescriptor.GetHashCode();
                }
                if (this.LepInstructionalProgramDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.LepInstructionalProgramDescriptor.GetHashCode();
                }
                if (this.BuildingCode != null)
                {
                    hashCode = (hashCode * 59) + this.BuildingCode.GetHashCode();
                }
                if (this.BuildingName != null)
                {
                    hashCode = (hashCode * 59) + this.BuildingName.GetHashCode();
                }
                if (this.DateOfBirth != null)
                {
                    hashCode = (hashCode * 59) + this.DateOfBirth.GetHashCode();
                }
                if (this.DistrictCode != null)
                {
                    hashCode = (hashCode * 59) + this.DistrictCode.GetHashCode();
                }
                if (this.DistrictName != null)
                {
                    hashCode = (hashCode * 59) + this.DistrictName.GetHashCode();
                }
                if (this.EconomicallyDisadvantaged != null)
                {
                    hashCode = (hashCode * 59) + this.EconomicallyDisadvantaged.GetHashCode();
                }
                if (this.EnglishAcademicYears != null)
                {
                    hashCode = (hashCode * 59) + this.EnglishAcademicYears.GetHashCode();
                }
                if (this.EnglishLearner != null)
                {
                    hashCode = (hashCode * 59) + this.EnglishLearner.GetHashCode();
                }
                if (this.FeederBuildingCode != null)
                {
                    hashCode = (hashCode * 59) + this.FeederBuildingCode.GetHashCode();
                }
                if (this.FirstName != null)
                {
                    hashCode = (hashCode * 59) + this.FirstName.GetHashCode();
                }
                if (this.FormerlyEnglishLearner != null)
                {
                    hashCode = (hashCode * 59) + this.FormerlyEnglishLearner.GetHashCode();
                }
                if (this.FosterCare != null)
                {
                    hashCode = (hashCode * 59) + this.FosterCare.GetHashCode();
                }
                if (this.Gender != null)
                {
                    hashCode = (hashCode * 59) + this.Gender.GetHashCode();
                }
                if (this.Homeless != null)
                {
                    hashCode = (hashCode * 59) + this.Homeless.GetHashCode();
                }
                if (this.HomeSchool != null)
                {
                    hashCode = (hashCode * 59) + this.HomeSchool.GetHashCode();
                }
                if (this.IsdCode != null)
                {
                    hashCode = (hashCode * 59) + this.IsdCode.GetHashCode();
                }
                if (this.IsdName != null)
                {
                    hashCode = (hashCode * 59) + this.IsdName.GetHashCode();
                }
                if (this.KnowledgeOfIEP != null)
                {
                    hashCode = (hashCode * 59) + this.KnowledgeOfIEP.GetHashCode();
                }
                if (this.LastSurname != null)
                {
                    hashCode = (hashCode * 59) + this.LastSurname.GetHashCode();
                }
                if (this.LiepOptionalData != null)
                {
                    hashCode = (hashCode * 59) + this.LiepOptionalData.GetHashCode();
                }
                if (this.LiepParentRefusal != null)
                {
                    hashCode = (hashCode * 59) + this.LiepParentRefusal.GetHashCode();
                }
                if (this.Ltfay != null)
                {
                    hashCode = (hashCode * 59) + this.Ltfay.GetHashCode();
                }
                if (this.MiddleName != null)
                {
                    hashCode = (hashCode * 59) + this.MiddleName.GetHashCode();
                }
                if (this.Migrant != null)
                {
                    hashCode = (hashCode * 59) + this.Migrant.GetHashCode();
                }
                if (this.MilitaryConnected != null)
                {
                    hashCode = (hashCode * 59) + this.MilitaryConnected.GetHashCode();
                }
                if (this.PrivateIndicator != null)
                {
                    hashCode = (hashCode * 59) + this.PrivateIndicator.GetHashCode();
                }
                if (this.SpecialEducation != null)
                {
                    hashCode = (hashCode * 59) + this.SpecialEducation.GetHashCode();
                }
                if (this.StudentIDNumber != null)
                {
                    hashCode = (hashCode * 59) + this.StudentIDNumber.GetHashCode();
                }
                if (this.YearsSchoolingUS != null)
                {
                    hashCode = (hashCode * 59) + this.YearsSchoolingUS.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // PrimaryDisabilityDescriptor (string) maxLength
            if (this.PrimaryDisabilityDescriptor != null && this.PrimaryDisabilityDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for PrimaryDisabilityDescriptor, length must be less than 306.", new [] { "PrimaryDisabilityDescriptor" });
            }

            // SecondaryDisabilityDescriptor (string) maxLength
            if (this.SecondaryDisabilityDescriptor != null && this.SecondaryDisabilityDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for SecondaryDisabilityDescriptor, length must be less than 306.", new [] { "SecondaryDisabilityDescriptor" });
            }

            // EthnicityDescriptor (string) maxLength
            if (this.EthnicityDescriptor != null && this.EthnicityDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EthnicityDescriptor, length must be less than 306.", new [] { "EthnicityDescriptor" });
            }

            // PrimaryLanguageDescriptor (string) maxLength
            if (this.PrimaryLanguageDescriptor != null && this.PrimaryLanguageDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for PrimaryLanguageDescriptor, length must be less than 306.", new [] { "PrimaryLanguageDescriptor" });
            }

            // LepInstructionalProgramDescriptor (string) maxLength
            if (this.LepInstructionalProgramDescriptor != null && this.LepInstructionalProgramDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for LepInstructionalProgramDescriptor, length must be less than 306.", new [] { "LepInstructionalProgramDescriptor" });
            }

            // BuildingCode (string) maxLength
            if (this.BuildingCode != null && this.BuildingCode.Length > 5)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for BuildingCode, length must be less than 5.", new [] { "BuildingCode" });
            }

            // BuildingName (string) maxLength
            if (this.BuildingName != null && this.BuildingName.Length > 255)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for BuildingName, length must be less than 255.", new [] { "BuildingName" });
            }

            // DistrictCode (string) maxLength
            if (this.DistrictCode != null && this.DistrictCode.Length > 5)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for DistrictCode, length must be less than 5.", new [] { "DistrictCode" });
            }

            // DistrictName (string) maxLength
            if (this.DistrictName != null && this.DistrictName.Length > 255)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for DistrictName, length must be less than 255.", new [] { "DistrictName" });
            }

            // EnglishAcademicYears (string) maxLength
            if (this.EnglishAcademicYears != null && this.EnglishAcademicYears.Length > 2)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EnglishAcademicYears, length must be less than 2.", new [] { "EnglishAcademicYears" });
            }

            // FeederBuildingCode (string) maxLength
            if (this.FeederBuildingCode != null && this.FeederBuildingCode.Length > 5)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for FeederBuildingCode, length must be less than 5.", new [] { "FeederBuildingCode" });
            }

            // FirstName (string) maxLength
            if (this.FirstName != null && this.FirstName.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for FirstName, length must be less than 75.", new [] { "FirstName" });
            }

            // Gender (string) maxLength
            if (this.Gender != null && this.Gender.Length > 1)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for Gender, length must be less than 1.", new [] { "Gender" });
            }

            // IsdCode (string) maxLength
            if (this.IsdCode != null && this.IsdCode.Length > 5)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for IsdCode, length must be less than 5.", new [] { "IsdCode" });
            }

            // IsdName (string) maxLength
            if (this.IsdName != null && this.IsdName.Length > 255)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for IsdName, length must be less than 255.", new [] { "IsdName" });
            }

            // LastSurname (string) maxLength
            if (this.LastSurname != null && this.LastSurname.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for LastSurname, length must be less than 75.", new [] { "LastSurname" });
            }

            // LiepOptionalData (string) maxLength
            if (this.LiepOptionalData != null && this.LiepOptionalData.Length > 9)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for LiepOptionalData, length must be less than 9.", new [] { "LiepOptionalData" });
            }

            // MiddleName (string) maxLength
            if (this.MiddleName != null && this.MiddleName.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for MiddleName, length must be less than 75.", new [] { "MiddleName" });
            }

            // StudentIDNumber (string) maxLength
            if (this.StudentIDNumber != null && this.StudentIDNumber.Length > 20)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for StudentIDNumber, length must be less than 20.", new [] { "StudentIDNumber" });
            }

            yield break;
        }
    }

}
