/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// MiStudentEarlyLearningProgramAssociation
    /// </summary>
    [DataContract(Name = "mi_studentEarlyLearningProgramAssociation")]
    public partial class MiStudentEarlyLearningProgramAssociation : IEquatable<MiStudentEarlyLearningProgramAssociation>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MiStudentEarlyLearningProgramAssociation" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected MiStudentEarlyLearningProgramAssociation() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="MiStudentEarlyLearningProgramAssociation" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="beginDate">The earliest date the student is involved with the program. Typically, this is the date the student becomes eligible for the program. (required).</param>
        /// <param name="educationOrganizationReference">educationOrganizationReference (required).</param>
        /// <param name="programReference">programReference (required).</param>
        /// <param name="studentReference">studentReference (required).</param>
        /// <param name="additionalEligibilityFactors">An unordered collection of studentEarlyLearningProgramAssociationAdditionalEligibilityFactors. Additional factors used to determine a child s eligibility for a Great Start Readiness Program, along with income information collected in the Federal Poverty Level Quintile (FPLQ) characteristic. For more information, reference the MDE GSRP Implementation Manual..</param>
        /// <param name="deliveryMethodDescriptor">The primary location where the student attends the reported program or receives early childhood services..</param>
        /// <param name="deliveryScheduleDescriptor">The primary schedule followed by the student for this program or service..</param>
        /// <param name="earlyLearningProgramServices">An unordered collection of studentEarlyLearningProgramAssociationEarlyLearningProgramServices. The student&#39;s program service information for early learning program..</param>
        /// <param name="ecComment">A field to provide users with the option of adding a comment to distinguish a child for their own records. This field is optional and is not required to be completed..</param>
        /// <param name="ecPrograms">An unordered collection of studentEarlyLearningProgramAssociationECPrograms. Indicates the early childhood program or service provided to the child..</param>
        /// <param name="eligibilityReasons">An unordered collection of studentEarlyLearningProgramAssociationEligibilityReasons. Describes the reason why a child was found eligible for Early On. Providers may report at least one code and may report up to 22 codes per record..</param>
        /// <param name="endDate">The month, day, and year on which the student exited the program or stopped receiving services..</param>
        /// <param name="federalPovertyLevelDescriptor">The Federal Poverty Level (FPL) quintile that a child belongs to..</param>
        /// <param name="individualizedFamilyServicePlan">individualizedFamilyServicePlan.</param>
        /// <param name="participationStatus">participationStatus.</param>
        /// <param name="programParticipationStatuses">An unordered collection of generalStudentProgramAssociationProgramParticipationStatuses. The status of the student&#39;s program participation..</param>
        /// <param name="providerLicenseNumber">The license number assigned to the location a child receives early childhood services. Licensed providers are assigned an 11-digit code (2 letters, 9 numbers) by the Michigan Department of Licensing and Regulatory Affairs. Tribal programs not licensed by the State are assigned a 14-digit code (7 letters, 7 numbers) by the Early Childhood Investment Corporation..</param>
        /// <param name="qualifyingFactors">An unordered collection of studentEarlyLearningProgramAssociationQualifyingFactors. Factors considered in determining the child s eligibility for a Great Start Readiness Program. Qualifying factors are those which automatically prioritize a child for enrollment. For more information, reference the MDE GSRP Implementation Manual..</param>
        /// <param name="reasonExitedDescriptor">The reason the student left the program within a school or district..</param>
        /// <param name="servedOutsideOfRegularSession">Indicates whether the student received services during the summer session or between sessions..</param>
        /// <param name="services">An unordered collection of studentEarlyLearningProgramAssociationServices. Indicates the Service(s) being provided to the Student by the Program..</param>
        /// <param name="workingParents">1 &#x3D; parent(s) are working and unavailable to care for the child during program hours. This could include a parent attending school or working a night shift requiring sleep during the day.0 &#x3D; the parents are not working and available to provide care during program hours..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public MiStudentEarlyLearningProgramAssociation(string id = default(string), DateTime beginDate = default(DateTime), EdFiEducationOrganizationReference educationOrganizationReference = default(EdFiEducationOrganizationReference), EdFiProgramReference programReference = default(EdFiProgramReference), EdFiStudentReference studentReference = default(EdFiStudentReference), List<MiStudentEarlyLearningProgramAssociationAdditionalEligibilityFactor> additionalEligibilityFactors = default(List<MiStudentEarlyLearningProgramAssociationAdditionalEligibilityFactor>), string deliveryMethodDescriptor = default(string), string deliveryScheduleDescriptor = default(string), List<MiStudentEarlyLearningProgramAssociationEarlyLearningProgramService> earlyLearningProgramServices = default(List<MiStudentEarlyLearningProgramAssociationEarlyLearningProgramService>), string ecComment = default(string), List<MiStudentEarlyLearningProgramAssociationECProgram> ecPrograms = default(List<MiStudentEarlyLearningProgramAssociationECProgram>), List<MiStudentEarlyLearningProgramAssociationEligibilityReason> eligibilityReasons = default(List<MiStudentEarlyLearningProgramAssociationEligibilityReason>), DateTime? endDate = default(DateTime?), string federalPovertyLevelDescriptor = default(string), MiStudentEarlyLearningProgramAssociationIndividualizedFamilyServicePlan individualizedFamilyServicePlan = default(MiStudentEarlyLearningProgramAssociationIndividualizedFamilyServicePlan), EdFiGeneralStudentProgramAssociationParticipationStatus participationStatus = default(EdFiGeneralStudentProgramAssociationParticipationStatus), List<EdFiGeneralStudentProgramAssociationProgramParticipationStatus> programParticipationStatuses = default(List<EdFiGeneralStudentProgramAssociationProgramParticipationStatus>), string providerLicenseNumber = default(string), List<MiStudentEarlyLearningProgramAssociationQualifyingFactor> qualifyingFactors = default(List<MiStudentEarlyLearningProgramAssociationQualifyingFactor>), string reasonExitedDescriptor = default(string), bool? servedOutsideOfRegularSession = default(bool?), List<MiStudentEarlyLearningProgramAssociationService> services = default(List<MiStudentEarlyLearningProgramAssociationService>), bool? workingParents = default(bool?), string etag = default(string))
        {
            this.BeginDate = beginDate;
            // to ensure "educationOrganizationReference" is required (not null)
            if (educationOrganizationReference == null)
            {
                throw new ArgumentNullException("educationOrganizationReference is a required property for MiStudentEarlyLearningProgramAssociation and cannot be null");
            }
            this.EducationOrganizationReference = educationOrganizationReference;
            // to ensure "programReference" is required (not null)
            if (programReference == null)
            {
                throw new ArgumentNullException("programReference is a required property for MiStudentEarlyLearningProgramAssociation and cannot be null");
            }
            this.ProgramReference = programReference;
            // to ensure "studentReference" is required (not null)
            if (studentReference == null)
            {
                throw new ArgumentNullException("studentReference is a required property for MiStudentEarlyLearningProgramAssociation and cannot be null");
            }
            this.StudentReference = studentReference;
            this.Id = id;
            this.AdditionalEligibilityFactors = additionalEligibilityFactors;
            this.DeliveryMethodDescriptor = deliveryMethodDescriptor;
            this.DeliveryScheduleDescriptor = deliveryScheduleDescriptor;
            this.EarlyLearningProgramServices = earlyLearningProgramServices;
            this.EcComment = ecComment;
            this.EcPrograms = ecPrograms;
            this.EligibilityReasons = eligibilityReasons;
            this.EndDate = endDate;
            this.FederalPovertyLevelDescriptor = federalPovertyLevelDescriptor;
            this.IndividualizedFamilyServicePlan = individualizedFamilyServicePlan;
            this.ParticipationStatus = participationStatus;
            this.ProgramParticipationStatuses = programParticipationStatuses;
            this.ProviderLicenseNumber = providerLicenseNumber;
            this.QualifyingFactors = qualifyingFactors;
            this.ReasonExitedDescriptor = reasonExitedDescriptor;
            this.ServedOutsideOfRegularSession = servedOutsideOfRegularSession;
            this.Services = services;
            this.WorkingParents = workingParents;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// The earliest date the student is involved with the program. Typically, this is the date the student becomes eligible for the program.
        /// </summary>
        /// <value>The earliest date the student is involved with the program. Typically, this is the date the student becomes eligible for the program.</value>
        [DataMember(Name = "beginDate", IsRequired = true, EmitDefaultValue = false)]
        [JsonConverter(typeof(OpenAPIDateConverter))]
        public DateTime BeginDate { get; set; }

        /// <summary>
        /// Gets or Sets EducationOrganizationReference
        /// </summary>
        [DataMember(Name = "educationOrganizationReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiEducationOrganizationReference EducationOrganizationReference { get; set; }

        /// <summary>
        /// Gets or Sets ProgramReference
        /// </summary>
        [DataMember(Name = "programReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiProgramReference ProgramReference { get; set; }

        /// <summary>
        /// Gets or Sets StudentReference
        /// </summary>
        [DataMember(Name = "studentReference", IsRequired = true, EmitDefaultValue = false)]
        public EdFiStudentReference StudentReference { get; set; }

        /// <summary>
        /// An unordered collection of studentEarlyLearningProgramAssociationAdditionalEligibilityFactors. Additional factors used to determine a child s eligibility for a Great Start Readiness Program, along with income information collected in the Federal Poverty Level Quintile (FPLQ) characteristic. For more information, reference the MDE GSRP Implementation Manual.
        /// </summary>
        /// <value>An unordered collection of studentEarlyLearningProgramAssociationAdditionalEligibilityFactors. Additional factors used to determine a child s eligibility for a Great Start Readiness Program, along with income information collected in the Federal Poverty Level Quintile (FPLQ) characteristic. For more information, reference the MDE GSRP Implementation Manual.</value>
        [DataMember(Name = "additionalEligibilityFactors", EmitDefaultValue = false)]
        public List<MiStudentEarlyLearningProgramAssociationAdditionalEligibilityFactor> AdditionalEligibilityFactors { get; set; }

        /// <summary>
        /// The primary location where the student attends the reported program or receives early childhood services.
        /// </summary>
        /// <value>The primary location where the student attends the reported program or receives early childhood services.</value>
        [DataMember(Name = "deliveryMethodDescriptor", EmitDefaultValue = true)]
        public string DeliveryMethodDescriptor { get; set; }

        /// <summary>
        /// The primary schedule followed by the student for this program or service.
        /// </summary>
        /// <value>The primary schedule followed by the student for this program or service.</value>
        [DataMember(Name = "deliveryScheduleDescriptor", EmitDefaultValue = true)]
        public string DeliveryScheduleDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of studentEarlyLearningProgramAssociationEarlyLearningProgramServices. The student&#39;s program service information for early learning program.
        /// </summary>
        /// <value>An unordered collection of studentEarlyLearningProgramAssociationEarlyLearningProgramServices. The student&#39;s program service information for early learning program.</value>
        [DataMember(Name = "earlyLearningProgramServices", EmitDefaultValue = false)]
        public List<MiStudentEarlyLearningProgramAssociationEarlyLearningProgramService> EarlyLearningProgramServices { get; set; }

        /// <summary>
        /// A field to provide users with the option of adding a comment to distinguish a child for their own records. This field is optional and is not required to be completed.
        /// </summary>
        /// <value>A field to provide users with the option of adding a comment to distinguish a child for their own records. This field is optional and is not required to be completed.</value>
        [DataMember(Name = "ecComment", EmitDefaultValue = true)]
        public string EcComment { get; set; }

        /// <summary>
        /// An unordered collection of studentEarlyLearningProgramAssociationECPrograms. Indicates the early childhood program or service provided to the child.
        /// </summary>
        /// <value>An unordered collection of studentEarlyLearningProgramAssociationECPrograms. Indicates the early childhood program or service provided to the child.</value>
        [DataMember(Name = "ecPrograms", EmitDefaultValue = false)]
        public List<MiStudentEarlyLearningProgramAssociationECProgram> EcPrograms { get; set; }

        /// <summary>
        /// An unordered collection of studentEarlyLearningProgramAssociationEligibilityReasons. Describes the reason why a child was found eligible for Early On. Providers may report at least one code and may report up to 22 codes per record.
        /// </summary>
        /// <value>An unordered collection of studentEarlyLearningProgramAssociationEligibilityReasons. Describes the reason why a child was found eligible for Early On. Providers may report at least one code and may report up to 22 codes per record.</value>
        [DataMember(Name = "eligibilityReasons", EmitDefaultValue = false)]
        public List<MiStudentEarlyLearningProgramAssociationEligibilityReason> EligibilityReasons { get; set; }

        /// <summary>
        /// The month, day, and year on which the student exited the program or stopped receiving services.
        /// </summary>
        /// <value>The month, day, and year on which the student exited the program or stopped receiving services.</value>
        [DataMember(Name = "endDate", EmitDefaultValue = true)]
        [JsonConverter(typeof(OpenAPIDateConverter))]
        public DateTime? EndDate { get; set; }

        /// <summary>
        /// The Federal Poverty Level (FPL) quintile that a child belongs to.
        /// </summary>
        /// <value>The Federal Poverty Level (FPL) quintile that a child belongs to.</value>
        [DataMember(Name = "federalPovertyLevelDescriptor", EmitDefaultValue = true)]
        public string FederalPovertyLevelDescriptor { get; set; }

        /// <summary>
        /// Gets or Sets IndividualizedFamilyServicePlan
        /// </summary>
        [DataMember(Name = "individualizedFamilyServicePlan", EmitDefaultValue = false)]
        public MiStudentEarlyLearningProgramAssociationIndividualizedFamilyServicePlan IndividualizedFamilyServicePlan { get; set; }

        /// <summary>
        /// Gets or Sets ParticipationStatus
        /// </summary>
        [DataMember(Name = "participationStatus", EmitDefaultValue = false)]
        public EdFiGeneralStudentProgramAssociationParticipationStatus ParticipationStatus { get; set; }

        /// <summary>
        /// An unordered collection of generalStudentProgramAssociationProgramParticipationStatuses. The status of the student&#39;s program participation.
        /// </summary>
        /// <value>An unordered collection of generalStudentProgramAssociationProgramParticipationStatuses. The status of the student&#39;s program participation.</value>
        [DataMember(Name = "programParticipationStatuses", EmitDefaultValue = false)]
        public List<EdFiGeneralStudentProgramAssociationProgramParticipationStatus> ProgramParticipationStatuses { get; set; }

        /// <summary>
        /// The license number assigned to the location a child receives early childhood services. Licensed providers are assigned an 11-digit code (2 letters, 9 numbers) by the Michigan Department of Licensing and Regulatory Affairs. Tribal programs not licensed by the State are assigned a 14-digit code (7 letters, 7 numbers) by the Early Childhood Investment Corporation.
        /// </summary>
        /// <value>The license number assigned to the location a child receives early childhood services. Licensed providers are assigned an 11-digit code (2 letters, 9 numbers) by the Michigan Department of Licensing and Regulatory Affairs. Tribal programs not licensed by the State are assigned a 14-digit code (7 letters, 7 numbers) by the Early Childhood Investment Corporation.</value>
        [DataMember(Name = "providerLicenseNumber", EmitDefaultValue = true)]
        public string ProviderLicenseNumber { get; set; }

        /// <summary>
        /// An unordered collection of studentEarlyLearningProgramAssociationQualifyingFactors. Factors considered in determining the child s eligibility for a Great Start Readiness Program. Qualifying factors are those which automatically prioritize a child for enrollment. For more information, reference the MDE GSRP Implementation Manual.
        /// </summary>
        /// <value>An unordered collection of studentEarlyLearningProgramAssociationQualifyingFactors. Factors considered in determining the child s eligibility for a Great Start Readiness Program. Qualifying factors are those which automatically prioritize a child for enrollment. For more information, reference the MDE GSRP Implementation Manual.</value>
        [DataMember(Name = "qualifyingFactors", EmitDefaultValue = false)]
        public List<MiStudentEarlyLearningProgramAssociationQualifyingFactor> QualifyingFactors { get; set; }

        /// <summary>
        /// The reason the student left the program within a school or district.
        /// </summary>
        /// <value>The reason the student left the program within a school or district.</value>
        [DataMember(Name = "reasonExitedDescriptor", EmitDefaultValue = true)]
        public string ReasonExitedDescriptor { get; set; }

        /// <summary>
        /// Indicates whether the student received services during the summer session or between sessions.
        /// </summary>
        /// <value>Indicates whether the student received services during the summer session or between sessions.</value>
        [DataMember(Name = "servedOutsideOfRegularSession", EmitDefaultValue = true)]
        public bool? ServedOutsideOfRegularSession { get; set; }

        /// <summary>
        /// An unordered collection of studentEarlyLearningProgramAssociationServices. Indicates the Service(s) being provided to the Student by the Program.
        /// </summary>
        /// <value>An unordered collection of studentEarlyLearningProgramAssociationServices. Indicates the Service(s) being provided to the Student by the Program.</value>
        [DataMember(Name = "services", EmitDefaultValue = false)]
        public List<MiStudentEarlyLearningProgramAssociationService> Services { get; set; }

        /// <summary>
        /// 1 &#x3D; parent(s) are working and unavailable to care for the child during program hours. This could include a parent attending school or working a night shift requiring sleep during the day.0 &#x3D; the parents are not working and available to provide care during program hours.
        /// </summary>
        /// <value>1 &#x3D; parent(s) are working and unavailable to care for the child during program hours. This could include a parent attending school or working a night shift requiring sleep during the day.0 &#x3D; the parents are not working and available to provide care during program hours.</value>
        [DataMember(Name = "workingParents", EmitDefaultValue = true)]
        public bool? WorkingParents { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class MiStudentEarlyLearningProgramAssociation {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  BeginDate: ").Append(BeginDate).Append("\n");
            sb.Append("  EducationOrganizationReference: ").Append(EducationOrganizationReference).Append("\n");
            sb.Append("  ProgramReference: ").Append(ProgramReference).Append("\n");
            sb.Append("  StudentReference: ").Append(StudentReference).Append("\n");
            sb.Append("  AdditionalEligibilityFactors: ").Append(AdditionalEligibilityFactors).Append("\n");
            sb.Append("  DeliveryMethodDescriptor: ").Append(DeliveryMethodDescriptor).Append("\n");
            sb.Append("  DeliveryScheduleDescriptor: ").Append(DeliveryScheduleDescriptor).Append("\n");
            sb.Append("  EarlyLearningProgramServices: ").Append(EarlyLearningProgramServices).Append("\n");
            sb.Append("  EcComment: ").Append(EcComment).Append("\n");
            sb.Append("  EcPrograms: ").Append(EcPrograms).Append("\n");
            sb.Append("  EligibilityReasons: ").Append(EligibilityReasons).Append("\n");
            sb.Append("  EndDate: ").Append(EndDate).Append("\n");
            sb.Append("  FederalPovertyLevelDescriptor: ").Append(FederalPovertyLevelDescriptor).Append("\n");
            sb.Append("  IndividualizedFamilyServicePlan: ").Append(IndividualizedFamilyServicePlan).Append("\n");
            sb.Append("  ParticipationStatus: ").Append(ParticipationStatus).Append("\n");
            sb.Append("  ProgramParticipationStatuses: ").Append(ProgramParticipationStatuses).Append("\n");
            sb.Append("  ProviderLicenseNumber: ").Append(ProviderLicenseNumber).Append("\n");
            sb.Append("  QualifyingFactors: ").Append(QualifyingFactors).Append("\n");
            sb.Append("  ReasonExitedDescriptor: ").Append(ReasonExitedDescriptor).Append("\n");
            sb.Append("  ServedOutsideOfRegularSession: ").Append(ServedOutsideOfRegularSession).Append("\n");
            sb.Append("  Services: ").Append(Services).Append("\n");
            sb.Append("  WorkingParents: ").Append(WorkingParents).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as MiStudentEarlyLearningProgramAssociation);
        }

        /// <summary>
        /// Returns true if MiStudentEarlyLearningProgramAssociation instances are equal
        /// </summary>
        /// <param name="input">Instance of MiStudentEarlyLearningProgramAssociation to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(MiStudentEarlyLearningProgramAssociation input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.BeginDate == input.BeginDate ||
                    (this.BeginDate != null &&
                    this.BeginDate.Equals(input.BeginDate))
                ) && 
                (
                    this.EducationOrganizationReference == input.EducationOrganizationReference ||
                    (this.EducationOrganizationReference != null &&
                    this.EducationOrganizationReference.Equals(input.EducationOrganizationReference))
                ) && 
                (
                    this.ProgramReference == input.ProgramReference ||
                    (this.ProgramReference != null &&
                    this.ProgramReference.Equals(input.ProgramReference))
                ) && 
                (
                    this.StudentReference == input.StudentReference ||
                    (this.StudentReference != null &&
                    this.StudentReference.Equals(input.StudentReference))
                ) && 
                (
                    this.AdditionalEligibilityFactors == input.AdditionalEligibilityFactors ||
                    this.AdditionalEligibilityFactors != null &&
                    input.AdditionalEligibilityFactors != null &&
                    this.AdditionalEligibilityFactors.SequenceEqual(input.AdditionalEligibilityFactors)
                ) && 
                (
                    this.DeliveryMethodDescriptor == input.DeliveryMethodDescriptor ||
                    (this.DeliveryMethodDescriptor != null &&
                    this.DeliveryMethodDescriptor.Equals(input.DeliveryMethodDescriptor))
                ) && 
                (
                    this.DeliveryScheduleDescriptor == input.DeliveryScheduleDescriptor ||
                    (this.DeliveryScheduleDescriptor != null &&
                    this.DeliveryScheduleDescriptor.Equals(input.DeliveryScheduleDescriptor))
                ) && 
                (
                    this.EarlyLearningProgramServices == input.EarlyLearningProgramServices ||
                    this.EarlyLearningProgramServices != null &&
                    input.EarlyLearningProgramServices != null &&
                    this.EarlyLearningProgramServices.SequenceEqual(input.EarlyLearningProgramServices)
                ) && 
                (
                    this.EcComment == input.EcComment ||
                    (this.EcComment != null &&
                    this.EcComment.Equals(input.EcComment))
                ) && 
                (
                    this.EcPrograms == input.EcPrograms ||
                    this.EcPrograms != null &&
                    input.EcPrograms != null &&
                    this.EcPrograms.SequenceEqual(input.EcPrograms)
                ) && 
                (
                    this.EligibilityReasons == input.EligibilityReasons ||
                    this.EligibilityReasons != null &&
                    input.EligibilityReasons != null &&
                    this.EligibilityReasons.SequenceEqual(input.EligibilityReasons)
                ) && 
                (
                    this.EndDate == input.EndDate ||
                    (this.EndDate != null &&
                    this.EndDate.Equals(input.EndDate))
                ) && 
                (
                    this.FederalPovertyLevelDescriptor == input.FederalPovertyLevelDescriptor ||
                    (this.FederalPovertyLevelDescriptor != null &&
                    this.FederalPovertyLevelDescriptor.Equals(input.FederalPovertyLevelDescriptor))
                ) && 
                (
                    this.IndividualizedFamilyServicePlan == input.IndividualizedFamilyServicePlan ||
                    (this.IndividualizedFamilyServicePlan != null &&
                    this.IndividualizedFamilyServicePlan.Equals(input.IndividualizedFamilyServicePlan))
                ) && 
                (
                    this.ParticipationStatus == input.ParticipationStatus ||
                    (this.ParticipationStatus != null &&
                    this.ParticipationStatus.Equals(input.ParticipationStatus))
                ) && 
                (
                    this.ProgramParticipationStatuses == input.ProgramParticipationStatuses ||
                    this.ProgramParticipationStatuses != null &&
                    input.ProgramParticipationStatuses != null &&
                    this.ProgramParticipationStatuses.SequenceEqual(input.ProgramParticipationStatuses)
                ) && 
                (
                    this.ProviderLicenseNumber == input.ProviderLicenseNumber ||
                    (this.ProviderLicenseNumber != null &&
                    this.ProviderLicenseNumber.Equals(input.ProviderLicenseNumber))
                ) && 
                (
                    this.QualifyingFactors == input.QualifyingFactors ||
                    this.QualifyingFactors != null &&
                    input.QualifyingFactors != null &&
                    this.QualifyingFactors.SequenceEqual(input.QualifyingFactors)
                ) && 
                (
                    this.ReasonExitedDescriptor == input.ReasonExitedDescriptor ||
                    (this.ReasonExitedDescriptor != null &&
                    this.ReasonExitedDescriptor.Equals(input.ReasonExitedDescriptor))
                ) && 
                (
                    this.ServedOutsideOfRegularSession == input.ServedOutsideOfRegularSession ||
                    (this.ServedOutsideOfRegularSession != null &&
                    this.ServedOutsideOfRegularSession.Equals(input.ServedOutsideOfRegularSession))
                ) && 
                (
                    this.Services == input.Services ||
                    this.Services != null &&
                    input.Services != null &&
                    this.Services.SequenceEqual(input.Services)
                ) && 
                (
                    this.WorkingParents == input.WorkingParents ||
                    (this.WorkingParents != null &&
                    this.WorkingParents.Equals(input.WorkingParents))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.BeginDate != null)
                {
                    hashCode = (hashCode * 59) + this.BeginDate.GetHashCode();
                }
                if (this.EducationOrganizationReference != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationReference.GetHashCode();
                }
                if (this.ProgramReference != null)
                {
                    hashCode = (hashCode * 59) + this.ProgramReference.GetHashCode();
                }
                if (this.StudentReference != null)
                {
                    hashCode = (hashCode * 59) + this.StudentReference.GetHashCode();
                }
                if (this.AdditionalEligibilityFactors != null)
                {
                    hashCode = (hashCode * 59) + this.AdditionalEligibilityFactors.GetHashCode();
                }
                if (this.DeliveryMethodDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.DeliveryMethodDescriptor.GetHashCode();
                }
                if (this.DeliveryScheduleDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.DeliveryScheduleDescriptor.GetHashCode();
                }
                if (this.EarlyLearningProgramServices != null)
                {
                    hashCode = (hashCode * 59) + this.EarlyLearningProgramServices.GetHashCode();
                }
                if (this.EcComment != null)
                {
                    hashCode = (hashCode * 59) + this.EcComment.GetHashCode();
                }
                if (this.EcPrograms != null)
                {
                    hashCode = (hashCode * 59) + this.EcPrograms.GetHashCode();
                }
                if (this.EligibilityReasons != null)
                {
                    hashCode = (hashCode * 59) + this.EligibilityReasons.GetHashCode();
                }
                if (this.EndDate != null)
                {
                    hashCode = (hashCode * 59) + this.EndDate.GetHashCode();
                }
                if (this.FederalPovertyLevelDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.FederalPovertyLevelDescriptor.GetHashCode();
                }
                if (this.IndividualizedFamilyServicePlan != null)
                {
                    hashCode = (hashCode * 59) + this.IndividualizedFamilyServicePlan.GetHashCode();
                }
                if (this.ParticipationStatus != null)
                {
                    hashCode = (hashCode * 59) + this.ParticipationStatus.GetHashCode();
                }
                if (this.ProgramParticipationStatuses != null)
                {
                    hashCode = (hashCode * 59) + this.ProgramParticipationStatuses.GetHashCode();
                }
                if (this.ProviderLicenseNumber != null)
                {
                    hashCode = (hashCode * 59) + this.ProviderLicenseNumber.GetHashCode();
                }
                if (this.QualifyingFactors != null)
                {
                    hashCode = (hashCode * 59) + this.QualifyingFactors.GetHashCode();
                }
                if (this.ReasonExitedDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.ReasonExitedDescriptor.GetHashCode();
                }
                if (this.ServedOutsideOfRegularSession != null)
                {
                    hashCode = (hashCode * 59) + this.ServedOutsideOfRegularSession.GetHashCode();
                }
                if (this.Services != null)
                {
                    hashCode = (hashCode * 59) + this.Services.GetHashCode();
                }
                if (this.WorkingParents != null)
                {
                    hashCode = (hashCode * 59) + this.WorkingParents.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // DeliveryMethodDescriptor (string) maxLength
            if (this.DeliveryMethodDescriptor != null && this.DeliveryMethodDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for DeliveryMethodDescriptor, length must be less than 306.", new [] { "DeliveryMethodDescriptor" });
            }

            // DeliveryScheduleDescriptor (string) maxLength
            if (this.DeliveryScheduleDescriptor != null && this.DeliveryScheduleDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for DeliveryScheduleDescriptor, length must be less than 306.", new [] { "DeliveryScheduleDescriptor" });
            }

            // EcComment (string) maxLength
            if (this.EcComment != null && this.EcComment.Length > 50)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EcComment, length must be less than 50.", new [] { "EcComment" });
            }

            // FederalPovertyLevelDescriptor (string) maxLength
            if (this.FederalPovertyLevelDescriptor != null && this.FederalPovertyLevelDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for FederalPovertyLevelDescriptor, length must be less than 306.", new [] { "FederalPovertyLevelDescriptor" });
            }

            // ProviderLicenseNumber (string) maxLength
            if (this.ProviderLicenseNumber != null && this.ProviderLicenseNumber.Length > 20)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ProviderLicenseNumber, length must be less than 20.", new [] { "ProviderLicenseNumber" });
            }

            // ReasonExitedDescriptor (string) maxLength
            if (this.ReasonExitedDescriptor != null && this.ReasonExitedDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ReasonExitedDescriptor, length must be less than 306.", new [] { "ReasonExitedDescriptor" });
            }

            yield break;
        }
    }

}
