/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// TrackedChangesMiEducationServiceProviderExpenditureKey
    /// </summary>
    [DataContract(Name = "trackedChanges_mi_educationServiceProviderExpenditureKey")]
    public partial class TrackedChangesMiEducationServiceProviderExpenditureKey : IEquatable<TrackedChangesMiEducationServiceProviderExpenditureKey>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TrackedChangesMiEducationServiceProviderExpenditureKey" /> class.
        /// </summary>
        /// <param name="espFunctionCodeDescriptor">To indicate the basic account identifier for ESP expenditures. It describes the activity for which a service or material is acquired..</param>
        /// <param name="espObjectCodeDescriptor">To indicate the service or commodity obtained as the result of a specific ESP expenditure..</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the ESP is submitted..</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education organization..</param>
        public TrackedChangesMiEducationServiceProviderExpenditureKey(string espFunctionCodeDescriptor = default(string), string espObjectCodeDescriptor = default(string), int fiscalYear = default(int), int educationOrganizationId = default(int))
        {
            this.EspFunctionCodeDescriptor = espFunctionCodeDescriptor;
            this.EspObjectCodeDescriptor = espObjectCodeDescriptor;
            this.FiscalYear = fiscalYear;
            this.EducationOrganizationId = educationOrganizationId;
        }

        /// <summary>
        /// To indicate the basic account identifier for ESP expenditures. It describes the activity for which a service or material is acquired.
        /// </summary>
        /// <value>To indicate the basic account identifier for ESP expenditures. It describes the activity for which a service or material is acquired.</value>
        [DataMember(Name = "espFunctionCodeDescriptor", EmitDefaultValue = false)]
        public string EspFunctionCodeDescriptor { get; set; }

        /// <summary>
        /// To indicate the service or commodity obtained as the result of a specific ESP expenditure.
        /// </summary>
        /// <value>To indicate the service or commodity obtained as the result of a specific ESP expenditure.</value>
        [DataMember(Name = "espObjectCodeDescriptor", EmitDefaultValue = false)]
        public string EspObjectCodeDescriptor { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the ESP is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the ESP is submitted.</value>
        [DataMember(Name = "fiscalYear", EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization.
        /// </summary>
        /// <value>The identifier assigned to an education organization.</value>
        [DataMember(Name = "educationOrganizationId", EmitDefaultValue = false)]
        public int EducationOrganizationId { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class TrackedChangesMiEducationServiceProviderExpenditureKey {\n");
            sb.Append("  EspFunctionCodeDescriptor: ").Append(EspFunctionCodeDescriptor).Append("\n");
            sb.Append("  EspObjectCodeDescriptor: ").Append(EspObjectCodeDescriptor).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  EducationOrganizationId: ").Append(EducationOrganizationId).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as TrackedChangesMiEducationServiceProviderExpenditureKey);
        }

        /// <summary>
        /// Returns true if TrackedChangesMiEducationServiceProviderExpenditureKey instances are equal
        /// </summary>
        /// <param name="input">Instance of TrackedChangesMiEducationServiceProviderExpenditureKey to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(TrackedChangesMiEducationServiceProviderExpenditureKey input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.EspFunctionCodeDescriptor == input.EspFunctionCodeDescriptor ||
                    (this.EspFunctionCodeDescriptor != null &&
                    this.EspFunctionCodeDescriptor.Equals(input.EspFunctionCodeDescriptor))
                ) && 
                (
                    this.EspObjectCodeDescriptor == input.EspObjectCodeDescriptor ||
                    (this.EspObjectCodeDescriptor != null &&
                    this.EspObjectCodeDescriptor.Equals(input.EspObjectCodeDescriptor))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.EducationOrganizationId == input.EducationOrganizationId ||
                    this.EducationOrganizationId.Equals(input.EducationOrganizationId)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.EspFunctionCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EspFunctionCodeDescriptor.GetHashCode();
                }
                if (this.EspObjectCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EspObjectCodeDescriptor.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                hashCode = (hashCode * 59) + this.EducationOrganizationId.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // EspFunctionCodeDescriptor (string) maxLength
            if (this.EspFunctionCodeDescriptor != null && this.EspFunctionCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EspFunctionCodeDescriptor, length must be less than 306.", new [] { "EspFunctionCodeDescriptor" });
            }

            // EspObjectCodeDescriptor (string) maxLength
            if (this.EspObjectCodeDescriptor != null && this.EspObjectCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EspObjectCodeDescriptor, length must be less than 306.", new [] { "EspObjectCodeDescriptor" });
            }

            yield break;
        }
    }

}
