/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// TrackedChangesMiExpenditureKey
    /// </summary>
    [DataContract(Name = "trackedChanges_mi_expenditureKey")]
    public partial class TrackedChangesMiExpenditureKey : IEquatable<TrackedChangesMiExpenditureKey>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TrackedChangesMiExpenditureKey" /> class.
        /// </summary>
        /// <param name="functionCodeDescriptor">To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired..</param>
        /// <param name="grantCodeDescriptor">To indicate various grant programs/funding source..</param>
        /// <param name="objectCodeDescriptor">To indicate the service or commodity obtained as the result of a specific expenditure..</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the expenditure is submitted..</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education organization..</param>
        /// <param name="schoolId">The identifier assigned to a school..</param>
        public TrackedChangesMiExpenditureKey(string functionCodeDescriptor = default(string), string grantCodeDescriptor = default(string), string objectCodeDescriptor = default(string), int fiscalYear = default(int), int educationOrganizationId = default(int), int schoolId = default(int))
        {
            this.FunctionCodeDescriptor = functionCodeDescriptor;
            this.GrantCodeDescriptor = grantCodeDescriptor;
            this.ObjectCodeDescriptor = objectCodeDescriptor;
            this.FiscalYear = fiscalYear;
            this.EducationOrganizationId = educationOrganizationId;
            this.SchoolId = schoolId;
        }

        /// <summary>
        /// To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired.
        /// </summary>
        /// <value>To indicate the basic account identifier for expenditures. It describes the activity for which a service or material is acquired.</value>
        [DataMember(Name = "functionCodeDescriptor", EmitDefaultValue = false)]
        public string FunctionCodeDescriptor { get; set; }

        /// <summary>
        /// To indicate various grant programs/funding source.
        /// </summary>
        /// <value>To indicate various grant programs/funding source.</value>
        [DataMember(Name = "grantCodeDescriptor", EmitDefaultValue = false)]
        public string GrantCodeDescriptor { get; set; }

        /// <summary>
        /// To indicate the service or commodity obtained as the result of a specific expenditure.
        /// </summary>
        /// <value>To indicate the service or commodity obtained as the result of a specific expenditure.</value>
        [DataMember(Name = "objectCodeDescriptor", EmitDefaultValue = false)]
        public string ObjectCodeDescriptor { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the expenditure is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the expenditure is submitted.</value>
        [DataMember(Name = "fiscalYear", EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization.
        /// </summary>
        /// <value>The identifier assigned to an education organization.</value>
        [DataMember(Name = "educationOrganizationId", EmitDefaultValue = false)]
        public int EducationOrganizationId { get; set; }

        /// <summary>
        /// The identifier assigned to a school.
        /// </summary>
        /// <value>The identifier assigned to a school.</value>
        [DataMember(Name = "schoolId", EmitDefaultValue = false)]
        public int SchoolId { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class TrackedChangesMiExpenditureKey {\n");
            sb.Append("  FunctionCodeDescriptor: ").Append(FunctionCodeDescriptor).Append("\n");
            sb.Append("  GrantCodeDescriptor: ").Append(GrantCodeDescriptor).Append("\n");
            sb.Append("  ObjectCodeDescriptor: ").Append(ObjectCodeDescriptor).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  EducationOrganizationId: ").Append(EducationOrganizationId).Append("\n");
            sb.Append("  SchoolId: ").Append(SchoolId).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as TrackedChangesMiExpenditureKey);
        }

        /// <summary>
        /// Returns true if TrackedChangesMiExpenditureKey instances are equal
        /// </summary>
        /// <param name="input">Instance of TrackedChangesMiExpenditureKey to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(TrackedChangesMiExpenditureKey input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.FunctionCodeDescriptor == input.FunctionCodeDescriptor ||
                    (this.FunctionCodeDescriptor != null &&
                    this.FunctionCodeDescriptor.Equals(input.FunctionCodeDescriptor))
                ) && 
                (
                    this.GrantCodeDescriptor == input.GrantCodeDescriptor ||
                    (this.GrantCodeDescriptor != null &&
                    this.GrantCodeDescriptor.Equals(input.GrantCodeDescriptor))
                ) && 
                (
                    this.ObjectCodeDescriptor == input.ObjectCodeDescriptor ||
                    (this.ObjectCodeDescriptor != null &&
                    this.ObjectCodeDescriptor.Equals(input.ObjectCodeDescriptor))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.EducationOrganizationId == input.EducationOrganizationId ||
                    this.EducationOrganizationId.Equals(input.EducationOrganizationId)
                ) && 
                (
                    this.SchoolId == input.SchoolId ||
                    this.SchoolId.Equals(input.SchoolId)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.FunctionCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.FunctionCodeDescriptor.GetHashCode();
                }
                if (this.GrantCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.GrantCodeDescriptor.GetHashCode();
                }
                if (this.ObjectCodeDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.ObjectCodeDescriptor.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                hashCode = (hashCode * 59) + this.EducationOrganizationId.GetHashCode();
                hashCode = (hashCode * 59) + this.SchoolId.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // FunctionCodeDescriptor (string) maxLength
            if (this.FunctionCodeDescriptor != null && this.FunctionCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for FunctionCodeDescriptor, length must be less than 306.", new [] { "FunctionCodeDescriptor" });
            }

            // GrantCodeDescriptor (string) maxLength
            if (this.GrantCodeDescriptor != null && this.GrantCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for GrantCodeDescriptor, length must be less than 306.", new [] { "GrantCodeDescriptor" });
            }

            // ObjectCodeDescriptor (string) maxLength
            if (this.ObjectCodeDescriptor != null && this.ObjectCodeDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ObjectCodeDescriptor, length must be less than 306.", new [] { "ObjectCodeDescriptor" });
            }

            yield break;
        }
    }

}
