/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.All
{
    /// <summary>
    /// TrackedChangesMiRevenueKey
    /// </summary>
    [DataContract(Name = "trackedChanges_mi_revenueKey")]
    public partial class TrackedChangesMiRevenueKey : IEquatable<TrackedChangesMiRevenueKey>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="TrackedChangesMiRevenueKey" /> class.
        /// </summary>
        /// <param name="revenueMajorClassDescriptor">The basic account identifier for recording transactions..</param>
        /// <param name="fiscalYear">Denotes the fiscal year for which the revenue is submitted..</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education organization..</param>
        public TrackedChangesMiRevenueKey(string revenueMajorClassDescriptor = default(string), int fiscalYear = default(int), int educationOrganizationId = default(int))
        {
            this.RevenueMajorClassDescriptor = revenueMajorClassDescriptor;
            this.FiscalYear = fiscalYear;
            this.EducationOrganizationId = educationOrganizationId;
        }

        /// <summary>
        /// The basic account identifier for recording transactions.
        /// </summary>
        /// <value>The basic account identifier for recording transactions.</value>
        [DataMember(Name = "revenueMajorClassDescriptor", EmitDefaultValue = false)]
        public string RevenueMajorClassDescriptor { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the revenue is submitted.
        /// </summary>
        /// <value>Denotes the fiscal year for which the revenue is submitted.</value>
        [DataMember(Name = "fiscalYear", EmitDefaultValue = false)]
        public int FiscalYear { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization.
        /// </summary>
        /// <value>The identifier assigned to an education organization.</value>
        [DataMember(Name = "educationOrganizationId", EmitDefaultValue = false)]
        public int EducationOrganizationId { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class TrackedChangesMiRevenueKey {\n");
            sb.Append("  RevenueMajorClassDescriptor: ").Append(RevenueMajorClassDescriptor).Append("\n");
            sb.Append("  FiscalYear: ").Append(FiscalYear).Append("\n");
            sb.Append("  EducationOrganizationId: ").Append(EducationOrganizationId).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as TrackedChangesMiRevenueKey);
        }

        /// <summary>
        /// Returns true if TrackedChangesMiRevenueKey instances are equal
        /// </summary>
        /// <param name="input">Instance of TrackedChangesMiRevenueKey to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(TrackedChangesMiRevenueKey input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.RevenueMajorClassDescriptor == input.RevenueMajorClassDescriptor ||
                    (this.RevenueMajorClassDescriptor != null &&
                    this.RevenueMajorClassDescriptor.Equals(input.RevenueMajorClassDescriptor))
                ) && 
                (
                    this.FiscalYear == input.FiscalYear ||
                    this.FiscalYear.Equals(input.FiscalYear)
                ) && 
                (
                    this.EducationOrganizationId == input.EducationOrganizationId ||
                    this.EducationOrganizationId.Equals(input.EducationOrganizationId)
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.RevenueMajorClassDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.RevenueMajorClassDescriptor.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.FiscalYear.GetHashCode();
                hashCode = (hashCode * 59) + this.EducationOrganizationId.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // RevenueMajorClassDescriptor (string) maxLength
            if (this.RevenueMajorClassDescriptor != null && this.RevenueMajorClassDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for RevenueMajorClassDescriptor, length must be less than 306.", new [] { "RevenueMajorClassDescriptor" });
            }

            yield break;
        }
    }

}
