/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.Composites.TestComposite
{
    /// <summary>
    /// School
    /// </summary>
    [DataContract(Name = "school")]
    public partial class School : IEquatable<School>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="School" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected School() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="School" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="educationOrganizationCategories">An unordered collection of educationOrganizationCategories.  (required).</param>
        /// <param name="gradeLevels">An unordered collection of schoolGradeLevels.  (required).</param>
        /// <param name="schoolId">The identifier assigned to a school. (required).</param>
        /// <param name="addresses">An unordered collection of educationOrganizationAddresses. .</param>
        /// <param name="administrativeFundingControlDescriptor">The type of education institution as classified by its funding source, for example public or private..</param>
        /// <param name="charterStatusDescriptor">A school or agency providing free public elementary or secondary education to eligible students under a specific charter granted by the state legislature or other appropriate authority and designated by such authority to be a charter school..</param>
        /// <param name="identificationCodes">An unordered collection of educationOrganizationIdentificationCodes. .</param>
        /// <param name="institutionTelephones">An unordered collection of educationOrganizationInstitutionTelephones. .</param>
        /// <param name="internationalAddresses">An unordered collection of educationOrganizationInternationalAddresses. .</param>
        /// <param name="localEducationAgencyReference">localEducationAgencyReference.</param>
        /// <param name="nameOfInstitution">The full, legally accepted name of the institution. (required).</param>
        /// <param name="operationalStatusDescriptor">The current operational status of the education organization (e.g., active, inactive)..</param>
        /// <param name="schoolCategories">An unordered collection of schoolCategories. .</param>
        /// <param name="shortNameOfInstitution">A short name for the institution..</param>
        /// <param name="titleIPartASchoolDesignationDescriptor">Denotes the Title I Part A designation for the school..</param>
        /// <param name="type">The type of education institution as classified by its primary focus..</param>
        /// <param name="webSite">The public web site address (URL) for the education organization..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public School(string id = default(string), List<SchoolEducationOrganizationCategory> educationOrganizationCategories = default(List<SchoolEducationOrganizationCategory>), List<SchoolSchoolGradeLevel> gradeLevels = default(List<SchoolSchoolGradeLevel>), int schoolId = default(int), List<SchoolEducationOrganizationAddress> addresses = default(List<SchoolEducationOrganizationAddress>), string administrativeFundingControlDescriptor = default(string), string charterStatusDescriptor = default(string), List<SchoolEducationOrganizationIdentificationCode> identificationCodes = default(List<SchoolEducationOrganizationIdentificationCode>), List<SchoolEducationOrganizationInstitutionTelephone> institutionTelephones = default(List<SchoolEducationOrganizationInstitutionTelephone>), List<SchoolEducationOrganizationInternationalAddress> internationalAddresses = default(List<SchoolEducationOrganizationInternationalAddress>), SchoolLocalEducationAgency localEducationAgencyReference = default(SchoolLocalEducationAgency), string nameOfInstitution = default(string), string operationalStatusDescriptor = default(string), List<SchoolSchoolCategory> schoolCategories = default(List<SchoolSchoolCategory>), string shortNameOfInstitution = default(string), string titleIPartASchoolDesignationDescriptor = default(string), string type = default(string), string webSite = default(string), string etag = default(string))
        {
            // to ensure "educationOrganizationCategories" is required (not null)
            if (educationOrganizationCategories == null)
            {
                throw new ArgumentNullException("educationOrganizationCategories is a required property for School and cannot be null");
            }
            this.EducationOrganizationCategories = educationOrganizationCategories;
            // to ensure "gradeLevels" is required (not null)
            if (gradeLevels == null)
            {
                throw new ArgumentNullException("gradeLevels is a required property for School and cannot be null");
            }
            this.GradeLevels = gradeLevels;
            this.SchoolId = schoolId;
            // to ensure "nameOfInstitution" is required (not null)
            if (nameOfInstitution == null)
            {
                throw new ArgumentNullException("nameOfInstitution is a required property for School and cannot be null");
            }
            this.NameOfInstitution = nameOfInstitution;
            this.Id = id;
            this.Addresses = addresses;
            this.AdministrativeFundingControlDescriptor = administrativeFundingControlDescriptor;
            this.CharterStatusDescriptor = charterStatusDescriptor;
            this.IdentificationCodes = identificationCodes;
            this.InstitutionTelephones = institutionTelephones;
            this.InternationalAddresses = internationalAddresses;
            this.LocalEducationAgencyReference = localEducationAgencyReference;
            this.OperationalStatusDescriptor = operationalStatusDescriptor;
            this.SchoolCategories = schoolCategories;
            this.ShortNameOfInstitution = shortNameOfInstitution;
            this.TitleIPartASchoolDesignationDescriptor = titleIPartASchoolDesignationDescriptor;
            this.Type = type;
            this.WebSite = webSite;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationCategories. 
        /// </summary>
        /// <value>An unordered collection of educationOrganizationCategories. </value>
        [DataMember(Name = "educationOrganizationCategories", IsRequired = true, EmitDefaultValue = false)]
        public List<SchoolEducationOrganizationCategory> EducationOrganizationCategories { get; set; }

        /// <summary>
        /// An unordered collection of schoolGradeLevels. 
        /// </summary>
        /// <value>An unordered collection of schoolGradeLevels. </value>
        [DataMember(Name = "gradeLevels", IsRequired = true, EmitDefaultValue = false)]
        public List<SchoolSchoolGradeLevel> GradeLevels { get; set; }

        /// <summary>
        /// The identifier assigned to a school.
        /// </summary>
        /// <value>The identifier assigned to a school.</value>
        [DataMember(Name = "schoolId", IsRequired = true, EmitDefaultValue = false)]
        public int SchoolId { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationAddresses. 
        /// </summary>
        /// <value>An unordered collection of educationOrganizationAddresses. </value>
        [DataMember(Name = "addresses", EmitDefaultValue = false)]
        public List<SchoolEducationOrganizationAddress> Addresses { get; set; }

        /// <summary>
        /// The type of education institution as classified by its funding source, for example public or private.
        /// </summary>
        /// <value>The type of education institution as classified by its funding source, for example public or private.</value>
        [DataMember(Name = "administrativeFundingControlDescriptor", EmitDefaultValue = true)]
        public string AdministrativeFundingControlDescriptor { get; set; }

        /// <summary>
        /// A school or agency providing free public elementary or secondary education to eligible students under a specific charter granted by the state legislature or other appropriate authority and designated by such authority to be a charter school.
        /// </summary>
        /// <value>A school or agency providing free public elementary or secondary education to eligible students under a specific charter granted by the state legislature or other appropriate authority and designated by such authority to be a charter school.</value>
        [DataMember(Name = "charterStatusDescriptor", EmitDefaultValue = true)]
        public string CharterStatusDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationIdentificationCodes. 
        /// </summary>
        /// <value>An unordered collection of educationOrganizationIdentificationCodes. </value>
        [DataMember(Name = "identificationCodes", EmitDefaultValue = false)]
        public List<SchoolEducationOrganizationIdentificationCode> IdentificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInstitutionTelephones. 
        /// </summary>
        /// <value>An unordered collection of educationOrganizationInstitutionTelephones. </value>
        [DataMember(Name = "institutionTelephones", EmitDefaultValue = false)]
        public List<SchoolEducationOrganizationInstitutionTelephone> InstitutionTelephones { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInternationalAddresses. 
        /// </summary>
        /// <value>An unordered collection of educationOrganizationInternationalAddresses. </value>
        [DataMember(Name = "internationalAddresses", EmitDefaultValue = false)]
        public List<SchoolEducationOrganizationInternationalAddress> InternationalAddresses { get; set; }

        /// <summary>
        /// Gets or Sets LocalEducationAgencyReference
        /// </summary>
        [DataMember(Name = "localEducationAgencyReference", EmitDefaultValue = false)]
        public SchoolLocalEducationAgency LocalEducationAgencyReference { get; set; }

        /// <summary>
        /// The full, legally accepted name of the institution.
        /// </summary>
        /// <value>The full, legally accepted name of the institution.</value>
        [DataMember(Name = "nameOfInstitution", IsRequired = true, EmitDefaultValue = false)]
        public string NameOfInstitution { get; set; }

        /// <summary>
        /// The current operational status of the education organization (e.g., active, inactive).
        /// </summary>
        /// <value>The current operational status of the education organization (e.g., active, inactive).</value>
        [DataMember(Name = "operationalStatusDescriptor", EmitDefaultValue = true)]
        public string OperationalStatusDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of schoolCategories. 
        /// </summary>
        /// <value>An unordered collection of schoolCategories. </value>
        [DataMember(Name = "schoolCategories", EmitDefaultValue = false)]
        public List<SchoolSchoolCategory> SchoolCategories { get; set; }

        /// <summary>
        /// A short name for the institution.
        /// </summary>
        /// <value>A short name for the institution.</value>
        [DataMember(Name = "shortNameOfInstitution", EmitDefaultValue = true)]
        public string ShortNameOfInstitution { get; set; }

        /// <summary>
        /// Denotes the Title I Part A designation for the school.
        /// </summary>
        /// <value>Denotes the Title I Part A designation for the school.</value>
        [DataMember(Name = "titleIPartASchoolDesignationDescriptor", EmitDefaultValue = true)]
        public string TitleIPartASchoolDesignationDescriptor { get; set; }

        /// <summary>
        /// The type of education institution as classified by its primary focus.
        /// </summary>
        /// <value>The type of education institution as classified by its primary focus.</value>
        [DataMember(Name = "type", EmitDefaultValue = true)]
        public string Type { get; set; }

        /// <summary>
        /// The public web site address (URL) for the education organization.
        /// </summary>
        /// <value>The public web site address (URL) for the education organization.</value>
        [DataMember(Name = "webSite", EmitDefaultValue = true)]
        public string WebSite { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class School {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  EducationOrganizationCategories: ").Append(EducationOrganizationCategories).Append("\n");
            sb.Append("  GradeLevels: ").Append(GradeLevels).Append("\n");
            sb.Append("  SchoolId: ").Append(SchoolId).Append("\n");
            sb.Append("  Addresses: ").Append(Addresses).Append("\n");
            sb.Append("  AdministrativeFundingControlDescriptor: ").Append(AdministrativeFundingControlDescriptor).Append("\n");
            sb.Append("  CharterStatusDescriptor: ").Append(CharterStatusDescriptor).Append("\n");
            sb.Append("  IdentificationCodes: ").Append(IdentificationCodes).Append("\n");
            sb.Append("  InstitutionTelephones: ").Append(InstitutionTelephones).Append("\n");
            sb.Append("  InternationalAddresses: ").Append(InternationalAddresses).Append("\n");
            sb.Append("  LocalEducationAgencyReference: ").Append(LocalEducationAgencyReference).Append("\n");
            sb.Append("  NameOfInstitution: ").Append(NameOfInstitution).Append("\n");
            sb.Append("  OperationalStatusDescriptor: ").Append(OperationalStatusDescriptor).Append("\n");
            sb.Append("  SchoolCategories: ").Append(SchoolCategories).Append("\n");
            sb.Append("  ShortNameOfInstitution: ").Append(ShortNameOfInstitution).Append("\n");
            sb.Append("  TitleIPartASchoolDesignationDescriptor: ").Append(TitleIPartASchoolDesignationDescriptor).Append("\n");
            sb.Append("  Type: ").Append(Type).Append("\n");
            sb.Append("  WebSite: ").Append(WebSite).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as School);
        }

        /// <summary>
        /// Returns true if School instances are equal
        /// </summary>
        /// <param name="input">Instance of School to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(School input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.EducationOrganizationCategories == input.EducationOrganizationCategories ||
                    this.EducationOrganizationCategories != null &&
                    input.EducationOrganizationCategories != null &&
                    this.EducationOrganizationCategories.SequenceEqual(input.EducationOrganizationCategories)
                ) && 
                (
                    this.GradeLevels == input.GradeLevels ||
                    this.GradeLevels != null &&
                    input.GradeLevels != null &&
                    this.GradeLevels.SequenceEqual(input.GradeLevels)
                ) && 
                (
                    this.SchoolId == input.SchoolId ||
                    this.SchoolId.Equals(input.SchoolId)
                ) && 
                (
                    this.Addresses == input.Addresses ||
                    this.Addresses != null &&
                    input.Addresses != null &&
                    this.Addresses.SequenceEqual(input.Addresses)
                ) && 
                (
                    this.AdministrativeFundingControlDescriptor == input.AdministrativeFundingControlDescriptor ||
                    (this.AdministrativeFundingControlDescriptor != null &&
                    this.AdministrativeFundingControlDescriptor.Equals(input.AdministrativeFundingControlDescriptor))
                ) && 
                (
                    this.CharterStatusDescriptor == input.CharterStatusDescriptor ||
                    (this.CharterStatusDescriptor != null &&
                    this.CharterStatusDescriptor.Equals(input.CharterStatusDescriptor))
                ) && 
                (
                    this.IdentificationCodes == input.IdentificationCodes ||
                    this.IdentificationCodes != null &&
                    input.IdentificationCodes != null &&
                    this.IdentificationCodes.SequenceEqual(input.IdentificationCodes)
                ) && 
                (
                    this.InstitutionTelephones == input.InstitutionTelephones ||
                    this.InstitutionTelephones != null &&
                    input.InstitutionTelephones != null &&
                    this.InstitutionTelephones.SequenceEqual(input.InstitutionTelephones)
                ) && 
                (
                    this.InternationalAddresses == input.InternationalAddresses ||
                    this.InternationalAddresses != null &&
                    input.InternationalAddresses != null &&
                    this.InternationalAddresses.SequenceEqual(input.InternationalAddresses)
                ) && 
                (
                    this.LocalEducationAgencyReference == input.LocalEducationAgencyReference ||
                    (this.LocalEducationAgencyReference != null &&
                    this.LocalEducationAgencyReference.Equals(input.LocalEducationAgencyReference))
                ) && 
                (
                    this.NameOfInstitution == input.NameOfInstitution ||
                    (this.NameOfInstitution != null &&
                    this.NameOfInstitution.Equals(input.NameOfInstitution))
                ) && 
                (
                    this.OperationalStatusDescriptor == input.OperationalStatusDescriptor ||
                    (this.OperationalStatusDescriptor != null &&
                    this.OperationalStatusDescriptor.Equals(input.OperationalStatusDescriptor))
                ) && 
                (
                    this.SchoolCategories == input.SchoolCategories ||
                    this.SchoolCategories != null &&
                    input.SchoolCategories != null &&
                    this.SchoolCategories.SequenceEqual(input.SchoolCategories)
                ) && 
                (
                    this.ShortNameOfInstitution == input.ShortNameOfInstitution ||
                    (this.ShortNameOfInstitution != null &&
                    this.ShortNameOfInstitution.Equals(input.ShortNameOfInstitution))
                ) && 
                (
                    this.TitleIPartASchoolDesignationDescriptor == input.TitleIPartASchoolDesignationDescriptor ||
                    (this.TitleIPartASchoolDesignationDescriptor != null &&
                    this.TitleIPartASchoolDesignationDescriptor.Equals(input.TitleIPartASchoolDesignationDescriptor))
                ) && 
                (
                    this.Type == input.Type ||
                    (this.Type != null &&
                    this.Type.Equals(input.Type))
                ) && 
                (
                    this.WebSite == input.WebSite ||
                    (this.WebSite != null &&
                    this.WebSite.Equals(input.WebSite))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.EducationOrganizationCategories != null)
                {
                    hashCode = (hashCode * 59) + this.EducationOrganizationCategories.GetHashCode();
                }
                if (this.GradeLevels != null)
                {
                    hashCode = (hashCode * 59) + this.GradeLevels.GetHashCode();
                }
                hashCode = (hashCode * 59) + this.SchoolId.GetHashCode();
                if (this.Addresses != null)
                {
                    hashCode = (hashCode * 59) + this.Addresses.GetHashCode();
                }
                if (this.AdministrativeFundingControlDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.AdministrativeFundingControlDescriptor.GetHashCode();
                }
                if (this.CharterStatusDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.CharterStatusDescriptor.GetHashCode();
                }
                if (this.IdentificationCodes != null)
                {
                    hashCode = (hashCode * 59) + this.IdentificationCodes.GetHashCode();
                }
                if (this.InstitutionTelephones != null)
                {
                    hashCode = (hashCode * 59) + this.InstitutionTelephones.GetHashCode();
                }
                if (this.InternationalAddresses != null)
                {
                    hashCode = (hashCode * 59) + this.InternationalAddresses.GetHashCode();
                }
                if (this.LocalEducationAgencyReference != null)
                {
                    hashCode = (hashCode * 59) + this.LocalEducationAgencyReference.GetHashCode();
                }
                if (this.NameOfInstitution != null)
                {
                    hashCode = (hashCode * 59) + this.NameOfInstitution.GetHashCode();
                }
                if (this.OperationalStatusDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.OperationalStatusDescriptor.GetHashCode();
                }
                if (this.SchoolCategories != null)
                {
                    hashCode = (hashCode * 59) + this.SchoolCategories.GetHashCode();
                }
                if (this.ShortNameOfInstitution != null)
                {
                    hashCode = (hashCode * 59) + this.ShortNameOfInstitution.GetHashCode();
                }
                if (this.TitleIPartASchoolDesignationDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.TitleIPartASchoolDesignationDescriptor.GetHashCode();
                }
                if (this.Type != null)
                {
                    hashCode = (hashCode * 59) + this.Type.GetHashCode();
                }
                if (this.WebSite != null)
                {
                    hashCode = (hashCode * 59) + this.WebSite.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // AdministrativeFundingControlDescriptor (string) maxLength
            if (this.AdministrativeFundingControlDescriptor != null && this.AdministrativeFundingControlDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for AdministrativeFundingControlDescriptor, length must be less than 306.", new [] { "AdministrativeFundingControlDescriptor" });
            }

            // CharterStatusDescriptor (string) maxLength
            if (this.CharterStatusDescriptor != null && this.CharterStatusDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for CharterStatusDescriptor, length must be less than 306.", new [] { "CharterStatusDescriptor" });
            }

            // NameOfInstitution (string) maxLength
            if (this.NameOfInstitution != null && this.NameOfInstitution.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for NameOfInstitution, length must be less than 75.", new [] { "NameOfInstitution" });
            }

            // OperationalStatusDescriptor (string) maxLength
            if (this.OperationalStatusDescriptor != null && this.OperationalStatusDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for OperationalStatusDescriptor, length must be less than 306.", new [] { "OperationalStatusDescriptor" });
            }

            // ShortNameOfInstitution (string) maxLength
            if (this.ShortNameOfInstitution != null && this.ShortNameOfInstitution.Length > 75)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for ShortNameOfInstitution, length must be less than 75.", new [] { "ShortNameOfInstitution" });
            }

            // TitleIPartASchoolDesignationDescriptor (string) maxLength
            if (this.TitleIPartASchoolDesignationDescriptor != null && this.TitleIPartASchoolDesignationDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for TitleIPartASchoolDesignationDescriptor, length must be less than 306.", new [] { "TitleIPartASchoolDesignationDescriptor" });
            }

            // Type (string) maxLength
            if (this.Type != null && this.Type.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for Type, length must be less than 306.", new [] { "Type" });
            }

            // WebSite (string) maxLength
            if (this.WebSite != null && this.WebSite.Length > 255)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for WebSite, length must be less than 255.", new [] { "WebSite" });
            }

            yield break;
        }
    }

}
