/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.Composites.TestComposite
{
    /// <summary>
    /// SectionEnrollment
    /// </summary>
    [DataContract(Name = "sectionEnrollment")]
    public partial class SectionEnrollment : IEquatable<SectionEnrollment>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="SectionEnrollment" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected SectionEnrollment() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="SectionEnrollment" /> class.
        /// </summary>
        /// <param name="id">id.</param>
        /// <param name="sectionIdentifier">The local identifier assigned to a section. (required).</param>
        /// <param name="academicSubjectDescriptor">The intended major subject area of the course..</param>
        /// <param name="availableCredits">The value of credits or units of value awarded for the completion of a course..</param>
        /// <param name="classPeriods">An unordered collection of sectionClassPeriods. .</param>
        /// <param name="courseOfferingReference">courseOfferingReference.</param>
        /// <param name="educationalEnvironmentDescriptor">The setting in which a student receives education and related services..</param>
        /// <param name="locationReference">locationReference.</param>
        /// <param name="locationSchoolReference">locationSchoolReference.</param>
        /// <param name="sequenceOfCourse">When a section is part of a sequence of parts for a course, the number of the sequence. If the course has only one part, the value of this section attribute should be 1..</param>
        /// <param name="sessionReference">sessionReference.</param>
        /// <param name="staff">An unordered collection of staffSectionAssociations. .</param>
        /// <param name="students">An unordered collection of studentSectionAssociations. .</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public SectionEnrollment(string id = default(string), string sectionIdentifier = default(string), string academicSubjectDescriptor = default(string), double? availableCredits = default(double?), List<SectionEnrollmentSectionClassPeriod> classPeriods = default(List<SectionEnrollmentSectionClassPeriod>), SectionEnrollmentCourseOffering courseOfferingReference = default(SectionEnrollmentCourseOffering), string educationalEnvironmentDescriptor = default(string), SectionEnrollmentLocation locationReference = default(SectionEnrollmentLocation), SectionEnrollmentSchool locationSchoolReference = default(SectionEnrollmentSchool), int? sequenceOfCourse = default(int?), SectionEnrollmentSession sessionReference = default(SectionEnrollmentSession), List<SectionEnrollmentStaffSectionAssociation> staff = default(List<SectionEnrollmentStaffSectionAssociation>), List<SectionEnrollmentStudentSectionAssociation> students = default(List<SectionEnrollmentStudentSectionAssociation>), string etag = default(string))
        {
            // to ensure "sectionIdentifier" is required (not null)
            if (sectionIdentifier == null)
            {
                throw new ArgumentNullException("sectionIdentifier is a required property for SectionEnrollment and cannot be null");
            }
            this.SectionIdentifier = sectionIdentifier;
            this.Id = id;
            this.AcademicSubjectDescriptor = academicSubjectDescriptor;
            this.AvailableCredits = availableCredits;
            this.ClassPeriods = classPeriods;
            this.CourseOfferingReference = courseOfferingReference;
            this.EducationalEnvironmentDescriptor = educationalEnvironmentDescriptor;
            this.LocationReference = locationReference;
            this.LocationSchoolReference = locationSchoolReference;
            this.SequenceOfCourse = sequenceOfCourse;
            this.SessionReference = sessionReference;
            this.Staff = staff;
            this.Students = students;
            this.Etag = etag;
        }

        /// <summary>
        /// Gets or Sets Id
        /// </summary>
        [DataMember(Name = "id", EmitDefaultValue = false)]
        public string Id { get; set; }

        /// <summary>
        /// The local identifier assigned to a section.
        /// </summary>
        /// <value>The local identifier assigned to a section.</value>
        [DataMember(Name = "sectionIdentifier", IsRequired = true, EmitDefaultValue = false)]
        public string SectionIdentifier { get; set; }

        /// <summary>
        /// The intended major subject area of the course.
        /// </summary>
        /// <value>The intended major subject area of the course.</value>
        [DataMember(Name = "academicSubjectDescriptor", EmitDefaultValue = true)]
        public string AcademicSubjectDescriptor { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        /// <value>The value of credits or units of value awarded for the completion of a course.</value>
        [DataMember(Name = "availableCredits", EmitDefaultValue = true)]
        public double? AvailableCredits { get; set; }

        /// <summary>
        /// An unordered collection of sectionClassPeriods. 
        /// </summary>
        /// <value>An unordered collection of sectionClassPeriods. </value>
        [DataMember(Name = "classPeriods", EmitDefaultValue = false)]
        public List<SectionEnrollmentSectionClassPeriod> ClassPeriods { get; set; }

        /// <summary>
        /// Gets or Sets CourseOfferingReference
        /// </summary>
        [DataMember(Name = "courseOfferingReference", EmitDefaultValue = false)]
        public SectionEnrollmentCourseOffering CourseOfferingReference { get; set; }

        /// <summary>
        /// The setting in which a student receives education and related services.
        /// </summary>
        /// <value>The setting in which a student receives education and related services.</value>
        [DataMember(Name = "educationalEnvironmentDescriptor", EmitDefaultValue = true)]
        public string EducationalEnvironmentDescriptor { get; set; }

        /// <summary>
        /// Gets or Sets LocationReference
        /// </summary>
        [DataMember(Name = "locationReference", EmitDefaultValue = false)]
        public SectionEnrollmentLocation LocationReference { get; set; }

        /// <summary>
        /// Gets or Sets LocationSchoolReference
        /// </summary>
        [DataMember(Name = "locationSchoolReference", EmitDefaultValue = false)]
        public SectionEnrollmentSchool LocationSchoolReference { get; set; }

        /// <summary>
        /// When a section is part of a sequence of parts for a course, the number of the sequence. If the course has only one part, the value of this section attribute should be 1.
        /// </summary>
        /// <value>When a section is part of a sequence of parts for a course, the number of the sequence. If the course has only one part, the value of this section attribute should be 1.</value>
        [DataMember(Name = "sequenceOfCourse", EmitDefaultValue = true)]
        public int? SequenceOfCourse { get; set; }

        /// <summary>
        /// Gets or Sets SessionReference
        /// </summary>
        [DataMember(Name = "sessionReference", EmitDefaultValue = false)]
        public SectionEnrollmentSession SessionReference { get; set; }

        /// <summary>
        /// An unordered collection of staffSectionAssociations. 
        /// </summary>
        /// <value>An unordered collection of staffSectionAssociations. </value>
        [DataMember(Name = "staff", EmitDefaultValue = false)]
        public List<SectionEnrollmentStaffSectionAssociation> Staff { get; set; }

        /// <summary>
        /// An unordered collection of studentSectionAssociations. 
        /// </summary>
        /// <value>An unordered collection of studentSectionAssociations. </value>
        [DataMember(Name = "students", EmitDefaultValue = false)]
        public List<SectionEnrollmentStudentSectionAssociation> Students { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class SectionEnrollment {\n");
            sb.Append("  Id: ").Append(Id).Append("\n");
            sb.Append("  SectionIdentifier: ").Append(SectionIdentifier).Append("\n");
            sb.Append("  AcademicSubjectDescriptor: ").Append(AcademicSubjectDescriptor).Append("\n");
            sb.Append("  AvailableCredits: ").Append(AvailableCredits).Append("\n");
            sb.Append("  ClassPeriods: ").Append(ClassPeriods).Append("\n");
            sb.Append("  CourseOfferingReference: ").Append(CourseOfferingReference).Append("\n");
            sb.Append("  EducationalEnvironmentDescriptor: ").Append(EducationalEnvironmentDescriptor).Append("\n");
            sb.Append("  LocationReference: ").Append(LocationReference).Append("\n");
            sb.Append("  LocationSchoolReference: ").Append(LocationSchoolReference).Append("\n");
            sb.Append("  SequenceOfCourse: ").Append(SequenceOfCourse).Append("\n");
            sb.Append("  SessionReference: ").Append(SessionReference).Append("\n");
            sb.Append("  Staff: ").Append(Staff).Append("\n");
            sb.Append("  Students: ").Append(Students).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as SectionEnrollment);
        }

        /// <summary>
        /// Returns true if SectionEnrollment instances are equal
        /// </summary>
        /// <param name="input">Instance of SectionEnrollment to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(SectionEnrollment input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.Id == input.Id ||
                    (this.Id != null &&
                    this.Id.Equals(input.Id))
                ) && 
                (
                    this.SectionIdentifier == input.SectionIdentifier ||
                    (this.SectionIdentifier != null &&
                    this.SectionIdentifier.Equals(input.SectionIdentifier))
                ) && 
                (
                    this.AcademicSubjectDescriptor == input.AcademicSubjectDescriptor ||
                    (this.AcademicSubjectDescriptor != null &&
                    this.AcademicSubjectDescriptor.Equals(input.AcademicSubjectDescriptor))
                ) && 
                (
                    this.AvailableCredits == input.AvailableCredits ||
                    (this.AvailableCredits != null &&
                    this.AvailableCredits.Equals(input.AvailableCredits))
                ) && 
                (
                    this.ClassPeriods == input.ClassPeriods ||
                    this.ClassPeriods != null &&
                    input.ClassPeriods != null &&
                    this.ClassPeriods.SequenceEqual(input.ClassPeriods)
                ) && 
                (
                    this.CourseOfferingReference == input.CourseOfferingReference ||
                    (this.CourseOfferingReference != null &&
                    this.CourseOfferingReference.Equals(input.CourseOfferingReference))
                ) && 
                (
                    this.EducationalEnvironmentDescriptor == input.EducationalEnvironmentDescriptor ||
                    (this.EducationalEnvironmentDescriptor != null &&
                    this.EducationalEnvironmentDescriptor.Equals(input.EducationalEnvironmentDescriptor))
                ) && 
                (
                    this.LocationReference == input.LocationReference ||
                    (this.LocationReference != null &&
                    this.LocationReference.Equals(input.LocationReference))
                ) && 
                (
                    this.LocationSchoolReference == input.LocationSchoolReference ||
                    (this.LocationSchoolReference != null &&
                    this.LocationSchoolReference.Equals(input.LocationSchoolReference))
                ) && 
                (
                    this.SequenceOfCourse == input.SequenceOfCourse ||
                    (this.SequenceOfCourse != null &&
                    this.SequenceOfCourse.Equals(input.SequenceOfCourse))
                ) && 
                (
                    this.SessionReference == input.SessionReference ||
                    (this.SessionReference != null &&
                    this.SessionReference.Equals(input.SessionReference))
                ) && 
                (
                    this.Staff == input.Staff ||
                    this.Staff != null &&
                    input.Staff != null &&
                    this.Staff.SequenceEqual(input.Staff)
                ) && 
                (
                    this.Students == input.Students ||
                    this.Students != null &&
                    input.Students != null &&
                    this.Students.SequenceEqual(input.Students)
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Id != null)
                {
                    hashCode = (hashCode * 59) + this.Id.GetHashCode();
                }
                if (this.SectionIdentifier != null)
                {
                    hashCode = (hashCode * 59) + this.SectionIdentifier.GetHashCode();
                }
                if (this.AcademicSubjectDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.AcademicSubjectDescriptor.GetHashCode();
                }
                if (this.AvailableCredits != null)
                {
                    hashCode = (hashCode * 59) + this.AvailableCredits.GetHashCode();
                }
                if (this.ClassPeriods != null)
                {
                    hashCode = (hashCode * 59) + this.ClassPeriods.GetHashCode();
                }
                if (this.CourseOfferingReference != null)
                {
                    hashCode = (hashCode * 59) + this.CourseOfferingReference.GetHashCode();
                }
                if (this.EducationalEnvironmentDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.EducationalEnvironmentDescriptor.GetHashCode();
                }
                if (this.LocationReference != null)
                {
                    hashCode = (hashCode * 59) + this.LocationReference.GetHashCode();
                }
                if (this.LocationSchoolReference != null)
                {
                    hashCode = (hashCode * 59) + this.LocationSchoolReference.GetHashCode();
                }
                if (this.SequenceOfCourse != null)
                {
                    hashCode = (hashCode * 59) + this.SequenceOfCourse.GetHashCode();
                }
                if (this.SessionReference != null)
                {
                    hashCode = (hashCode * 59) + this.SessionReference.GetHashCode();
                }
                if (this.Staff != null)
                {
                    hashCode = (hashCode * 59) + this.Staff.GetHashCode();
                }
                if (this.Students != null)
                {
                    hashCode = (hashCode * 59) + this.Students.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // SectionIdentifier (string) maxLength
            if (this.SectionIdentifier != null && this.SectionIdentifier.Length > 255)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for SectionIdentifier, length must be less than 255.", new [] { "SectionIdentifier" });
            }

            // AcademicSubjectDescriptor (string) maxLength
            if (this.AcademicSubjectDescriptor != null && this.AcademicSubjectDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for AcademicSubjectDescriptor, length must be less than 306.", new [] { "AcademicSubjectDescriptor" });
            }

            // EducationalEnvironmentDescriptor (string) maxLength
            if (this.EducationalEnvironmentDescriptor != null && this.EducationalEnvironmentDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for EducationalEnvironmentDescriptor, length must be less than 306.", new [] { "EducationalEnvironmentDescriptor" });
            }

            yield break;
        }
    }

}
