/*
 * Ed-Fi Operational Data Store API
 *
 * The Ed-Fi ODS / API enables applications to read and write education data stored in an Ed-Fi ODS through a secure REST interface.  ***  > *Note: Consumers of ODS / API information should sanitize all data for display and storage. The ODS / API provides reasonable safeguards against cross-site scripting attacks and other malicious content, but the platform does not and cannot guarantee that the data it contains is free of all potentially harmful content.*  *** 
 *
 * The version of the OpenAPI document: 3
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = EdFi.OdsApi.Sdk.Client.OpenAPIDateConverter;

namespace EdFi.OdsApi.Sdk.Models.Composites.TestComposite
{
    /// <summary>
    /// StudentAssessmentWithUniqueIdAndDescriptor
    /// </summary>
    [DataContract(Name = "studentAssessmentWithUniqueIdAndDescriptor")]
    public partial class StudentAssessmentWithUniqueIdAndDescriptor : IEquatable<StudentAssessmentWithUniqueIdAndDescriptor>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="StudentAssessmentWithUniqueIdAndDescriptor" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected StudentAssessmentWithUniqueIdAndDescriptor() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="StudentAssessmentWithUniqueIdAndDescriptor" /> class.
        /// </summary>
        /// <param name="studentUniqueId">A unique alphanumeric code assigned to a student. (required).</param>
        /// <param name="administrationDate">The date and time an assessment was completed by the student. The use of ISO-8601 formats with a timezone designator (UTC or time offset) is recommended in order to prevent ambiguity due to time zones..</param>
        /// <param name="administrationEnvironmentDescriptor">The environment in which the test was administered..</param>
        /// <param name="administrationLanguageDescriptor">The language in which an assessment is written and/or administered..</param>
        /// <param name="etag">A unique system-generated value that identifies the version of the resource..</param>
        public StudentAssessmentWithUniqueIdAndDescriptor(string studentUniqueId = default(string), DateTime? administrationDate = default(DateTime?), string administrationEnvironmentDescriptor = default(string), string administrationLanguageDescriptor = default(string), string etag = default(string))
        {
            // to ensure "studentUniqueId" is required (not null)
            if (studentUniqueId == null)
            {
                throw new ArgumentNullException("studentUniqueId is a required property for StudentAssessmentWithUniqueIdAndDescriptor and cannot be null");
            }
            this.StudentUniqueId = studentUniqueId;
            this.AdministrationDate = administrationDate;
            this.AdministrationEnvironmentDescriptor = administrationEnvironmentDescriptor;
            this.AdministrationLanguageDescriptor = administrationLanguageDescriptor;
            this.Etag = etag;
        }

        /// <summary>
        /// A unique alphanumeric code assigned to a student.
        /// </summary>
        /// <value>A unique alphanumeric code assigned to a student.</value>
        [DataMember(Name = "studentUniqueId", IsRequired = true, EmitDefaultValue = false)]
        public string StudentUniqueId { get; set; }

        /// <summary>
        /// The date and time an assessment was completed by the student. The use of ISO-8601 formats with a timezone designator (UTC or time offset) is recommended in order to prevent ambiguity due to time zones.
        /// </summary>
        /// <value>The date and time an assessment was completed by the student. The use of ISO-8601 formats with a timezone designator (UTC or time offset) is recommended in order to prevent ambiguity due to time zones.</value>
        [DataMember(Name = "administrationDate", EmitDefaultValue = true)]
        public DateTime? AdministrationDate { get; set; }

        /// <summary>
        /// The environment in which the test was administered.
        /// </summary>
        /// <value>The environment in which the test was administered.</value>
        [DataMember(Name = "administrationEnvironmentDescriptor", EmitDefaultValue = true)]
        public string AdministrationEnvironmentDescriptor { get; set; }

        /// <summary>
        /// The language in which an assessment is written and/or administered.
        /// </summary>
        /// <value>The language in which an assessment is written and/or administered.</value>
        [DataMember(Name = "administrationLanguageDescriptor", EmitDefaultValue = true)]
        public string AdministrationLanguageDescriptor { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        /// <value>A unique system-generated value that identifies the version of the resource.</value>
        [DataMember(Name = "_etag", EmitDefaultValue = false)]
        public string Etag { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class StudentAssessmentWithUniqueIdAndDescriptor {\n");
            sb.Append("  StudentUniqueId: ").Append(StudentUniqueId).Append("\n");
            sb.Append("  AdministrationDate: ").Append(AdministrationDate).Append("\n");
            sb.Append("  AdministrationEnvironmentDescriptor: ").Append(AdministrationEnvironmentDescriptor).Append("\n");
            sb.Append("  AdministrationLanguageDescriptor: ").Append(AdministrationLanguageDescriptor).Append("\n");
            sb.Append("  Etag: ").Append(Etag).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as StudentAssessmentWithUniqueIdAndDescriptor);
        }

        /// <summary>
        /// Returns true if StudentAssessmentWithUniqueIdAndDescriptor instances are equal
        /// </summary>
        /// <param name="input">Instance of StudentAssessmentWithUniqueIdAndDescriptor to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(StudentAssessmentWithUniqueIdAndDescriptor input)
        {
            if (input == null)
            {
                return false;
            }
            return 
                (
                    this.StudentUniqueId == input.StudentUniqueId ||
                    (this.StudentUniqueId != null &&
                    this.StudentUniqueId.Equals(input.StudentUniqueId))
                ) && 
                (
                    this.AdministrationDate == input.AdministrationDate ||
                    (this.AdministrationDate != null &&
                    this.AdministrationDate.Equals(input.AdministrationDate))
                ) && 
                (
                    this.AdministrationEnvironmentDescriptor == input.AdministrationEnvironmentDescriptor ||
                    (this.AdministrationEnvironmentDescriptor != null &&
                    this.AdministrationEnvironmentDescriptor.Equals(input.AdministrationEnvironmentDescriptor))
                ) && 
                (
                    this.AdministrationLanguageDescriptor == input.AdministrationLanguageDescriptor ||
                    (this.AdministrationLanguageDescriptor != null &&
                    this.AdministrationLanguageDescriptor.Equals(input.AdministrationLanguageDescriptor))
                ) && 
                (
                    this.Etag == input.Etag ||
                    (this.Etag != null &&
                    this.Etag.Equals(input.Etag))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.StudentUniqueId != null)
                {
                    hashCode = (hashCode * 59) + this.StudentUniqueId.GetHashCode();
                }
                if (this.AdministrationDate != null)
                {
                    hashCode = (hashCode * 59) + this.AdministrationDate.GetHashCode();
                }
                if (this.AdministrationEnvironmentDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.AdministrationEnvironmentDescriptor.GetHashCode();
                }
                if (this.AdministrationLanguageDescriptor != null)
                {
                    hashCode = (hashCode * 59) + this.AdministrationLanguageDescriptor.GetHashCode();
                }
                if (this.Etag != null)
                {
                    hashCode = (hashCode * 59) + this.Etag.GetHashCode();
                }
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        public IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> Validate(ValidationContext validationContext)
        {
            // StudentUniqueId (string) maxLength
            if (this.StudentUniqueId != null && this.StudentUniqueId.Length > 32)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for StudentUniqueId, length must be less than 32.", new [] { "StudentUniqueId" });
            }

            // AdministrationEnvironmentDescriptor (string) maxLength
            if (this.AdministrationEnvironmentDescriptor != null && this.AdministrationEnvironmentDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for AdministrationEnvironmentDescriptor, length must be less than 306.", new [] { "AdministrationEnvironmentDescriptor" });
            }

            // AdministrationLanguageDescriptor (string) maxLength
            if (this.AdministrationLanguageDescriptor != null && this.AdministrationLanguageDescriptor.Length > 306)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for AdministrationLanguageDescriptor, length must be less than 306.", new [] { "AdministrationLanguageDescriptor" });
            }

            yield break;
        }
    }

}
